@@ -1,11 +1,12 @@
-from PyQt5 import QtGui, QtWidgets
-from PyQt5.QtCore import Qt, QObject, pyqtSignal, QLocale, QByteArray
+import pymodaq.daq_utils.gui_utils.file_io
+from qtpy import QtGui, QtWidgets
+from qtpy.QtCore import Qt, QObject, Signal, QByteArray
 
 import sys
 import pymodaq
 import pymodaq.daq_utils.parameter.ioxml
-from pymodaq.daq_utils.plotting.viewer1D.viewer1D_main import Viewer1D
-from pymodaq.daq_utils.plotting.viewer2D.viewer2D_main import Viewer2D
+from pymodaq.daq_utils.plotting.data_viewers.viewer1D import Viewer1D
+from pymodaq.daq_utils.plotting.data_viewers.viewer2D import Viewer2D
 
 from collections import OrderedDict
 import numpy as np
@@ -51,14 +52,14 @@ class DAQ_Analysis(QtWidgets.QWidget, QObject):
 
         References
         ----------
-        PyQt5, pyqtgraph, QtWidgets, QObject
+        qtpy, pyqtgraph, QtWidgets, QObject
 
     """
-    command_DAQ_signal = pyqtSignal(list)
-    log_signal = pyqtSignal(str)
+    command_DAQ_signal = Signal(list)
+    log_signal = Signal(str)
 
     def __init__(self, parent=None, title=None):
-        QLocale.setDefault(QLocale(QLocale.English, QLocale.UnitedStates))
+        
         super(DAQ_Analysis, self).__init__()
         if parent is None:
             raise Exception('no valid parent container, expected dockarea')
@@ -259,7 +260,7 @@ class DAQ_Analysis(QtWidgets.QWidget, QObject):
             open_h5_file, update_status, daq_utils.select_file
         """
         try:
-            filename = gutils.select_file(start_path=path, save=False, ext='h5')
+            filename = pymodaq.daq_utils.gui_utils.file_io.select_file(start_path=path, save=False, ext='h5')
             if filename != "":
                 self.open_h5_file(filename)
         except Exception as e:
