@@ -1,9 +1,11 @@
-from PyQt5 import QtGui, QtWidgets
-from PyQt5.QtCore import QObject, pyqtSlot, QThread, pyqtSignal, QLocale, Qt
+from pymodaq.daq_utils import config
+from qtpy import QtGui, QtWidgets
+from qtpy.QtCore import QObject, Slot, QThread, Signal, QLocale, Qt
 import sys
 from pymodaq.daq_move.daq_move_gui import Ui_Form
 
 from pymodaq.daq_move.utility_classes import params as daq_move_params
+from pymodaq.daq_move.utility_classes import MoveCommand
 from pathlib import Path
 
 from pyqtgraph.parametertree import Parameter, ParameterTree
@@ -17,8 +19,9 @@ from pymodaq.daq_utils.daq_utils import ThreadCommand
 from easydict import EasyDict as edict
 from pymodaq.daq_utils.tcp_server_client import TCPClient
 from pymodaq.daq_utils import daq_utils as utils
-
-local_path = utils.get_set_local_dir()
+from pymodaq.daq_utils.exceptions import ActuatorError
+from pymodaq.daq_utils import config
+local_path = config.get_set_local_dir()
 sys.path.append(local_path)
 
 logger = utils.set_logger(utils.get_module_name(__file__))
@@ -26,6 +29,7 @@ logger = utils.set_logger(utils.get_module_name(__file__))
 DAQ_Move_Stage_type = utils.get_plugins('daq_move')
 
 
+
 class DAQ_Move(Ui_Form, QObject):
     """
         | DAQ_Move object is a module used to control one motor from a specified list.
@@ -36,11 +40,11 @@ class DAQ_Move(Ui_Form, QObject):
 
         ========================= =================================================
         **Attributes**             **Type**
-        *command_stage*            instance of pyqtSignal
-        *move_done_signal*         instance of pyqtSignal
-        *update_settings_signal*   instance of pyqtSignal
-        *status_signal*               instance of pyqtSignal
-        *bounds_signal*            instance of pyqtSignal
+        *command_stage*            instance of Signal
+        *move_done_signal*         instance of Signal
+        *update_settings_signal*   instance of Signal
+        *status_signal*               instance of Signal
+        *bounds_signal*            instance of Signal
         *params*                   dictionnary list
         *ui*                       instance of UI_Form
         *parent*                   QObject
@@ -62,30 +66,29 @@ class DAQ_Move(Ui_Form, QObject):
 
         References
         ----------
-        QLocale, QObject, pyqtSignal, QStatusBar, ParameterTree
+        QLocale, QObject, Signal, QStatusBar, ParameterTree
     """
-    init_signal = pyqtSignal(bool)
-    command_stage = pyqtSignal(ThreadCommand)
-    command_tcpip = pyqtSignal(ThreadCommand)
-    move_done_signal = pyqtSignal(str,
+    init_signal = Signal(bool)
+    command_stage = Signal(ThreadCommand)
+    command_tcpip = Signal(ThreadCommand)
+    move_done_signal = Signal(str,
                                   float)  # to be used in external program to make sure the move has been done, export the current position. str refer to the unique title given to the module
-    update_settings_signal = pyqtSignal(edict)
-    status_signal = pyqtSignal(str)
-    bounds_signal = pyqtSignal(bool)
+    update_settings_signal = Signal(edict)
+    status_signal = Signal(str)
+    bounds_signal = Signal(bool)
     params = daq_move_params
 
-    def __init__(self, parent, title="pymodaq Move", preset=None, init=False, controller_ID=-1):
+    def __init__(self, parent, title="pymodaq Move", init=False):
         """DAQ_Move object is a module used to control one motor from a specified list.
         managers is an optional list of dicts used to managers programatically settings such as the name of the
         controller from the list of possible controllers, COM address...
         init is a boolean to tell the programm to initialize the controller at the start of the programm given the
         managers options
-        controller_ID is a unique random integer generated by the parent caller.
         To differenciate various instance of this class
         """
         self.logger = utils.set_logger(f'{logger.name}.{title}')
         self.logger.info(f'Initializing DAQ_Move: {title}')
-        QLocale.setDefault(QLocale(QLocale.English, QLocale.UnitedStates))
+        
         super().__init__()
 
         here = Path(__file__).parent
@@ -147,7 +150,6 @@ class DAQ_Move(Ui_Form, QObject):
             self.parameter_tree_changed)  # any changes on the settings will update accordingly the detector
         self.ui.settings_tree.setVisible(False)
         self.set_setting_tree()
-        self.settings.child('main_settings', 'controller_ID').setValue(controller_ID)
 
         QtWidgets.QApplication.processEvents()
         # #Connecting buttons:
@@ -171,19 +173,23 @@ class DAQ_Move(Ui_Form, QObject):
         self.ui.Abs_position_sb_bis.valueChanged.connect(self.ui.Abs_position_sb.setValue)
         self.ui.Moveto_pb_bis.clicked.connect(lambda: self.move_Abs(self.ui.Abs_position_sb_bis.value()))
 
-        # set managers options
-        if preset is not None:
-            for preset_dict in preset:
-                # fo instance preset_dict=dict(object='Stage_type_combo',method='setCurrentIndex',value=1)
-                if hasattr(self.ui, preset_dict['object']):
-                    obj = getattr(self.ui, preset_dict['object'])
-                    if hasattr(obj, preset_dict['method']):
-                        setattr(obj, preset_dict['method'], preset_dict['value'])
-            QtWidgets.QApplication.processEvents()
         # initialize the controller if init=True
         if init:
             self.ui.IniStage_pb.click()
 
+    @property
+    def actuator(self):
+        return self.ui.Stage_type_combo.currentText()
+
+    @actuator.setter
+    def actuator(self, actuator):
+        self.ui.Stage_type_combo.setCurrentText(actuator)
+        if self.actuator != actuator:
+            raise ActuatorError(f'{actuator} is not a valid installed actuator: {self.stage_types}')
+
+    def init(self):
+        self.ui.IniStage_pb.click()
+
     def ini_stage_fun(self):
         """
             Init :
@@ -240,6 +246,15 @@ class DAQ_Move(Ui_Form, QObject):
         except Exception as e:
             self.logger.exception(str(e))
 
+    def move(self, move_command: MoveCommand):
+        """Public method to trigger the correct action on the actuator. Should be used by external applications"""
+        if move_command.move_type == 'abs':
+            self.move_Abs(move_command.value)
+        elif move_command.move_type == 'rel':
+            self.move_Rel(move_command.value)
+        elif move_command.move_type == 'home':
+            self.move_Home(move_command.value)
+
     def move_Abs(self, position, send_to_tcpip=False):
         """
             | Make the move from an absolute position.
@@ -390,7 +405,7 @@ class DAQ_Move(Ui_Form, QObject):
             self.tcpclient_thread.start()
             tcpclient.init_connection()
 
-    @pyqtSlot(ThreadCommand)
+    @Slot(ThreadCommand)
     def process_tcpip_cmds(self, status):
         if 'move_abs' in status.command:
             self.move_Abs(status.attributes[0], send_to_tcpip=True)
@@ -450,7 +465,7 @@ class DAQ_Move(Ui_Form, QObject):
             if ret == QtWidgets.QMessageBox.Yes:
                 self.parent.close()
 
-    @pyqtSlot()
+    @Slot()
     def raise_timeout(self):
         """
             Update status with "Timeout occured" statement.
@@ -482,7 +497,7 @@ class DAQ_Move(Ui_Form, QObject):
         self.ui.Abs_position_sb_bis.setEnabled(enable)
         self.ui.Current_position_sb.setEnabled(enable)
 
-    @pyqtSlot(int)
+    @Slot(int)
     def set_setting_tree(self, index=0):
         """
             Set the move settings parameters tree, clearing the current tree and setting the 'move_settings' node.
@@ -526,7 +541,7 @@ class DAQ_Move(Ui_Form, QObject):
         else:
             self.ui.settings_tree.setVisible(False)
 
-    @pyqtSlot(int)
+    @Slot(int)
     def stage_changed(self, index=0):
 
         """
@@ -550,7 +565,7 @@ class DAQ_Move(Ui_Form, QObject):
         except Exception as e:
             self.logger.exception(str(e))
 
-    @pyqtSlot(ThreadCommand)
+    @Slot(ThreadCommand)
     def thread_status(self, status):  # general function to get datas/infos from all threads back to the main
         """
             | General function to get datas/infos from all threads back to the main0
@@ -692,6 +707,23 @@ class DAQ_Move(Ui_Form, QObject):
             self.splash_sc.close()
             self.ui.settings_tree.setEnabled(True)
 
+        elif status.command == 'set_allowed_values':
+            if 'decimals' in status.attributes:
+                self.ui.Current_position_sb.setDecimals(status.attributes['decimals'])
+                self.ui.Abs_position_sb.setDecimals(status.attributes['decimals'])
+                self.ui.Abs_position_sb_bis.setDecimals(status.attributes['decimals'])
+            if 'minimum'in status.attributes:
+                self.ui.Current_position_sb.setMinimum(status.attributes['minimum'])
+                self.ui.Abs_position_sb.setMinimum(status.attributes['minimum'])
+                self.ui.Abs_position_sb_bis.setMinimum(status.attributes['minimum'])
+            if 'maximum'in status.attributes:
+                self.ui.Current_position_sb.setMaximum(status.attributes['maximum'])
+                self.ui.Abs_position_sb.setMaximum(status.attributes['maximum'])
+                self.ui.Abs_position_sb_bis.setMaximum(status.attributes['maximum'])
+            if 'step'in status.attributes:
+                self.ui.Current_position_sb.setSingleStep(status.attributes['step'])
+                self.ui.Abs_position_sb.setSingleStep(status.attributes['step'])
+                self.ui.Abs_position_sb_bis.setSingleStep(status.attributes['step'])
 
     def update_status(self, txt, wait_time=0):
         """
@@ -714,7 +746,7 @@ class DAQ_Move_stage(QObject):
     """
         ================== ========================
         **Attributes**      **Type**
-        *status_sig*        instance of pyqtSignal
+        *status_sig*        instance of Signal
         *hardware*          ???
         *stage_name*        string
         *current_position*  float
@@ -724,11 +756,12 @@ class DAQ_Move_stage(QObject):
         *motion_stoped*     boolean
         ================== ========================
     """
-    status_sig = pyqtSignal(ThreadCommand)
+    status_sig = Signal(ThreadCommand)
 
     def __init__(self, stage_name, position, title='actuator'):
         super().__init__()
         self.logger = utils.set_logger(f'{logger.name}.{title}.actuator')
+        self.title = title
         self.hardware = None
         self.stage_name = stage_name
         self.current_position = position
@@ -789,7 +822,7 @@ class DAQ_Move_stage(QObject):
             self.logger.exception(str(e))
             return status
 
-    def move_Abs(self, position):
+    def move_Abs(self, position, polling=True):
         """
             Make the hardware absolute move from the given position.
 
@@ -804,9 +837,12 @@ class DAQ_Move_stage(QObject):
             move_Abs
         """
         self.target_position = position
+        self.hardware.move_is_done = False
+        self.hardware.ispolling = polling
         pos = self.hardware.move_Abs(position)
+        self.hardware.poll_moving()
 
-    def move_Rel(self, rel_position):
+    def move_Rel(self, rel_position, polling=True):
         """
             Make the hardware relative move from the given relative position added to the current one.
 
@@ -820,10 +856,13 @@ class DAQ_Move_stage(QObject):
             --------
             move_Rel
         """
+        self.hardware.move_is_done = False
         self.target_position = self.current_position + rel_position
+        self.hardware.ispolling = polling
         pos = self.hardware.move_Rel(rel_position)
+        self.hardware.poll_moving()
 
-    @pyqtSlot(float)
+    @Slot(float)
     def Move_Stoped(self, pos):
         """
             Send a "move_done" Thread Command with the given position as an attribute.
@@ -839,10 +878,11 @@ class DAQ_Move_stage(QObject):
             Make the hardware move to the init position.
 
         """
+        self.hardware.move_is_done = False
         self.target_position = 0
         self.hardware.move_Home()
 
-    @pyqtSlot(float)
+    @Slot(float)
     def Move_Done(self, pos):
         """
             | Send a "move_done" Thread Command with the given position as an attribute and update the current position attribute.
@@ -865,7 +905,7 @@ class DAQ_Move_stage(QObject):
         #    else:
         #        self.status_sig.emit(ThreadCommand("move_done",[pos]))
 
-    @pyqtSlot(ThreadCommand)
+    @Slot(ThreadCommand)
     def queue_command(self, command=ThreadCommand()):
         """
             Interpret the given Thread Command.
@@ -918,7 +958,7 @@ class DAQ_Move_stage(QObject):
 
             else:  # custom commands for particular plugins (see spectrometer module 'get_spectro_wl' for instance)
                 if hasattr(self.hardware, command.command):
-                    cmd = getattr(self.detector, command.command)
+                    cmd = getattr(self.hardware, command.command)
                     cmd(*command.attributes)
         except Exception as e:
             self.logger.exception(str(e))
@@ -934,8 +974,9 @@ class DAQ_Move_stage(QObject):
         self.status_sig.emit(ThreadCommand(command="Update_Status", attributes=["Motion stoping", 'log']))
         self.motion_stoped = True
         self.hardware.stop_motion()
+        self.hardware.poll_timer.stop()
 
-    @pyqtSlot(edict)
+    @Slot(edict)
     def update_settings(self, settings_parameter_dict):
         """
             Update settings of hardware with dictionnary parameters in case of "Move_Settings" path, else update attributes with dictionnary parameters.
@@ -961,14 +1002,17 @@ class DAQ_Move_stage(QObject):
             self.hardware.update_settings(settings_parameter_dict)
 
 
-def main():
-    app = QtWidgets.QApplication(sys.argv)
-    Form = QtWidgets.QWidget()
-    prog = DAQ_Move(Form, title="test", preset=[dict(object='Stage_type_combo', method='setCurrentText', value='Mock')],
-                    init=False)
-    Form.show()
-    sys.exit(app.exec_())
+def main(init_qt=True):
+    if init_qt: # used for the test suite
+        app = QtWidgets.QApplication(sys.argv)
 
+    form = QtWidgets.QWidget()
+    prog = DAQ_Move(form, title="test", init=False)
+    form.show()
+
+    if init_qt:
+        sys.exit(app.exec_())
+    return prog, form
 
 if __name__ == '__main__':
     main()
