@@ -1,20 +1,26 @@
-from PyQt5 import QtWidgets
-from PyQt5.QtCore import QObject, pyqtSlot, QThread, pyqtSignal
-# from enum import IntEnum
+from qtpy import QtWidgets
+from qtpy.QtCore import QObject, Slot, QThread, Signal, QTimer
+
 from easydict import EasyDict as edict
-from pymodaq.daq_utils.parameter.utils import iter_children
+import pymodaq.daq_utils.daq_utils as utils
+import pymodaq.daq_utils.parameter.utils as putils
 from pymodaq.daq_utils.parameter import ioxml
-import pymodaq.daq_utils.parameter.utils
 from pyqtgraph.parametertree import Parameter
-from pymodaq.daq_utils.daq_utils import ThreadCommand, getLineInfo, load_config
+from pymodaq.daq_utils.daq_utils import ThreadCommand, getLineInfo
+from pymodaq.daq_utils.config import Config
 from pymodaq.daq_utils.tcp_server_client import TCPServer, tcp_parameters
 import numpy as np
+from time import perf_counter
+
+logger = utils.set_logger(utils.get_module_name(__file__))
+config = Config()
 
-config = load_config()
 comon_parameters = [{'title': 'Units:', 'name': 'units', 'type': 'str', 'value': '', 'readonly': True},
-                    {'title': 'Epsilon:', 'name': 'epsilon', 'type': 'float', 'value': 0.01,
+                    {'title': 'Epsilon:', 'name': 'epsilon', 'type': 'float',
+                     'value': config('actuator', 'epsilon_default'),
                      'tip': 'Differential Value at which the controller considers it reached the target position'},
-                    {'title': 'Timeout (ms):', 'name': 'timeout', 'type': 'int', 'value': 10000, 'default': 10000},
+                    {'title': 'Timeout (ms):', 'name': 'timeout', 'type': 'int',
+                     'value': config('actuator', 'polling_timeout_s')},
 
                     {'title': 'Bounds:', 'name': 'bounds', 'type': 'group', 'children': [
                         {'title': 'Set Bounds:', 'name': 'is_bounds', 'type': 'bool', 'value': False},
@@ -26,6 +32,28 @@ comon_parameters = [{'title': 'Units:', 'name': 'units', 'type': 'str', 'value':
                          'default': False},
                         {'title': 'Scaling factor:', 'name': 'scaling', 'type': 'float', 'value': 1., 'default': 1.},
                         {'title': 'Offset factor:', 'name': 'offset', 'type': 'float', 'value': 0., 'default': 0.}]}]
+MOVE_COMMANDS = ['abs', 'rel', 'home']
+
+
+class MoveCommand:
+    def __init__(self, move_type, value=0):
+        if move_type not in MOVE_COMMANDS:
+            raise ValueError(f'The allowed move types fro an actuator are {MOVE_COMMANDS}')
+        self.move_type = move_type
+        self.value = value
+
+
+def comon_parameters_fun(is_multiaxes=False, stage_names=[], master=True):
+    params = [{'title': 'MultiAxes:', 'name': 'multiaxes', 'type': 'group', 'visible': is_multiaxes, 'children': [
+        {'title': 'is Multiaxes:', 'name': 'ismultiaxes', 'type': 'bool', 'value': is_multiaxes,
+         'default': False},
+        {'title': 'Status:', 'name': 'multi_status', 'type': 'list', 'value': 'Master' if master else 'Slave',
+         'limits': ['Master', 'Slave']},
+        {'title': 'Axis:', 'name': 'axis', 'type': 'list', 'limits': stage_names},
+
+    ]}] + comon_parameters
+    return params
+
 
 params = [
     {'title': 'Main Settings:', 'name': 'main_settings', 'type': 'group', 'children': [
@@ -37,14 +65,40 @@ params = [
               'value': False},
              {'title': 'Connected?:', 'name': 'tcp_connected', 'type': 'led', 'value': False},
              {'title': 'IP address:', 'name': 'ip_address', 'type': 'str',
-              'value': config['network']['tcp-server']['ip']},
-             {'title': 'Port:', 'name': 'port', 'type': 'int', 'value': config['network']['tcp-server']['port']},
+              'value': config('network', 'tcp-server', 'ip')},
+             {'title': 'Port:', 'name': 'port', 'type': 'int', 'value': config('network', 'tcp-server', 'port')},
          ]},
     ]},
     {'title': 'Actuator Settings:', 'name': 'move_settings', 'type': 'group'}
 ]
 
 
+def main(plugin_file, init=True, title='test'):
+    """
+    this method start a DAQ_Move object with this defined plugin as actuator
+    Returns
+    -------
+
+    """
+    import sys
+    from qtpy import QtWidgets
+    from pymodaq.daq_move.daq_move_main import DAQ_Move
+    from pathlib import Path
+    app = QtWidgets.QApplication(sys.argv)
+    if config('style', 'darkstyle'):
+        import qdarkstyle
+        app.setStyleSheet(qdarkstyle.load_stylesheet())
+
+    Form = QtWidgets.QWidget()
+    prog = DAQ_Move(Form, title=title,)
+    Form.show()
+    prog.actuator = Path(plugin_file).stem[9:]
+    if init:
+        prog.init()
+
+    sys.exit(app.exec_())
+
+
 class DAQ_Move_base(QObject):
     """ The base class to be herited by all actuator modules
 
@@ -57,7 +111,7 @@ class DAQ_Move_base(QObject):
     params_state : Parameter instance (pyqtgraph) from which the module will get the initial settings (as defined in the managers)
 
 
-    :ivar Move_Done_signal: pyqtSignal signal represented by a float. Is emitted each time the hardware reached the target
+    :ivar Move_Done_signal: Signal signal represented by a float. Is emitted each time the hardware reached the target
                             position within the epsilon precision (see comon_parameters variable)
 
     :ivar controller: the object representing the hardware in the plugin. Used to access hardware functionality
@@ -81,10 +135,12 @@ class DAQ_Move_base(QObject):
 
     """
 
-    Move_Done_signal = pyqtSignal(float)
+    Move_Done_signal = Signal(float)
     is_multiaxes = False
+    stage_names = []
     params = []
     _controller_units = ''
+    _epsilon = 1
 
     def __init__(self, parent=None, params_state=None):
         QObject.__init__(self)  # to make sure this is the parent class
@@ -93,8 +149,9 @@ class DAQ_Move_base(QObject):
         self.shamrock_controller = None
         self.stage = None
         self.status = edict(info="", controller=None, stage=None, initialized=False)
-        self.current_position = 0
-        self.target_position = 0
+        self.current_position = 0.
+        self.target_position = 0.
+        self._ispolling = True
         self.parent_parameters_path = []  # this is to be added in the send_param_status to take into account when the
         # current class instance parameter list is a child of some other class
         self.settings = Parameter.create(name='Settings', type='group', children=self.params)
@@ -106,6 +163,12 @@ class DAQ_Move_base(QObject):
 
         self.settings.sigTreeStateChanged.connect(self.send_param_status)
         self.controller_units = self._controller_units
+        self.settings.child('epsilon').setValue(self._epsilon)
+
+        self.poll_timer = QTimer()
+        self.poll_timer.setInterval(config('actuator', 'polling_interval_ms'))
+        self._poll_timeout = config('actuator', 'polling_timeout_s')
+        self.poll_timer.timeout.connect(self.check_target_reached)
 
     @property
     def controller_units(self):
@@ -115,10 +178,18 @@ class DAQ_Move_base(QObject):
     def controller_units(self, units: str = ''):
         self._controller_units = units
         try:
-            self.settings.child(('units')).setValue(units)
+            self.settings.child('units').setValue(units)
         except Exception:
             pass
 
+    @property
+    def ispolling(self):
+        return self._ispolling
+
+    @ispolling.setter
+    def ispolling(self, polling=True):
+        self._ispolling = polling
+
     def check_bound(self, position):
         """
 
@@ -130,7 +201,6 @@ class DAQ_Move_base(QObject):
         -------
 
         """
-        self.move_is_done = False
         if self.settings.child('bounds', 'is_bounds').value():
             if position > self.settings.child('bounds', 'max_bound').value():
                 position = self.settings.child('bounds', 'max_bound').value()
@@ -200,7 +270,8 @@ class DAQ_Move_base(QObject):
             =============== ========== =============================================================================
 
         """
-        position = self.check_position()
+        if position is None:
+            position = self.check_position()
         self.Move_Done_signal.emit(position)
         self.move_is_done = True
 
@@ -212,25 +283,32 @@ class DAQ_Move_base(QObject):
             --------
             DAQ_utils.ThreadCommand, move_done
         """
-        sleep_ms = 50
-        ind = 0
-        self.current_position = self.check_position()
-        while np.abs(self.check_position() - self.target_position) > self.settings.child(('epsilon')).value():
+        self.start_time = perf_counter()
+        if self.ispolling:
+            self.poll_timer.start()
+        else:
+            self.current_position = self.check_position()
+            logger.debug(f'Current position: {self.current_position}')
+            self.move_done(self.current_position)
+
+    def check_target_reached(self):
+        if np.abs(self.current_position - self.target_position) > self.settings.child('epsilon').value():
+            logger.debug(f'Check move_is_done: {self.move_is_done}')
             if self.move_is_done:
                 self.emit_status(ThreadCommand('Move has been stopped'))
-                break
-            QThread.msleep(sleep_ms)
-
-            ind += 1
-
-            if ind * sleep_ms >= self.settings.child(('timeout')).value():
-                self.emit_status(ThreadCommand('raise_timeout'))
-                break
+                logger.info(f'Move has been stopped')
 
             self.current_position = self.check_position()
-            QtWidgets.QApplication.processEvents()
+            logger.debug(f'Current position: {self.current_position}')
 
-        self.move_done()
+            if perf_counter() - self.start_time >= self.settings.child('timeout').value():
+                self.poll_timer.stop()
+                self.emit_status(ThreadCommand('raise_timeout'))
+                logger.info(f'Timeout activated')
+        else:
+            self.poll_timer.stop()
+            logger.debug(f'Current position: {self.current_position}')
+            self.move_done(self.current_position)
 
     def send_param_status(self, param, changes):
         """
@@ -287,7 +365,7 @@ class DAQ_Move_base(QObject):
             pos = pos / self.settings.child('scaling', 'scaling').value()
         return pos
 
-    @pyqtSlot(edict)
+    @Slot(edict)
     def update_settings(self, settings_parameter_dict):  # settings_parameter_dict=edict(path=path,param=param)
         """
             Receive the settings_parameter signal from the param_tree_changed method and make hardware updates of mmodified values.
@@ -317,10 +395,10 @@ class DAQ_Move_base(QObject):
             param = child
 
         elif change == 'parent':
-            children = pymodaq.daq_utils.parameter.utils.get_param_from_name(self.settings, param.name())
+            children = putils.get_param_from_name(self.settings, param.name())
 
             if children is not None:
-                path = pymodaq.daq_utils.parameter.utils.get_param_path(children)
+                path = putils.get_param_path(children)
                 self.settings.child(*path[1:-1]).removeChild(children)
 
         self.settings.sigTreeStateChanged.connect(self.send_param_status)
@@ -332,7 +410,7 @@ class DAQ_Move_TCP_server(DAQ_Move_base, TCPServer):
     """
         ================= ==============================
         **Attributes**      **Type**
-        *command_server*    instance of pyqtSignal
+        *command_server*    instance of Signal
         *x_axis*            1D numpy array
         *y_axis*            1D numpy array
         *data*              double precision float array
@@ -343,7 +421,7 @@ class DAQ_Move_TCP_server(DAQ_Move_base, TCPServer):
         utility_classes.DAQ_TCP_server
     """
     params_client = []  # parameters of a client grabber
-    command_server = pyqtSignal(list)
+    command_server = Signal(list)
 
     message_list = ["Quit", "Status", "Done", "Server Closed", "Info", "Infos", "Info_xml", "move_abs",
                     'move_home', 'move_rel', 'check_position', 'stop_motion', 'position_is', 'move_done']
@@ -387,10 +465,10 @@ class DAQ_Move_TCP_server(DAQ_Move_base, TCPServer):
 
     def commit_settings(self, param):
 
-        if param.name() in iter_children(self.settings.child(('settings_client')), []):
+        if param.name() in putils.iter_children(self.settings.child(('settings_client')), []):
             actuator_socket = [client['socket'] for client in self.connected_clients if client['type'] == 'ACTUATOR'][0]
             actuator_socket.send_string('set_info')
-            path = pymodaq.daq_utils.parameter.utils.get_param_path(param)[2:]
+            path = putils.get_param_path(param)[2:]
             # get the path of this param as a list starting at parent 'infos'
 
             actuator_socket.send_list(path)
