@@ -1,7 +1,30 @@
-from PyQt5 import QtCore
-from PyQt5.QtCore import QVariant
+import os
 import sys
+from collections import OrderedDict
+from ctypes import CFUNCTYPE
+
+from pymodaq.daq_utils.config import get_set_config_path, get_set_preset_path, Config
+from pymodaq.daq_utils.messenger import deprecation_msg
+if 'win32' in sys.platform:
+    from ctypes import WINFUNCTYPE
+import datetime
+import importlib
+import inspect
+import json
+import logging
+import functools
+import time
+from logging.handlers import TimedRotatingFileHandler
 from packaging import version as version_mod
+from pathlib import Path
+import pkgutil
+import traceback
+import warnings
+
+import numpy as np
+from qtpy import QtCore
+from qtpy.QtCore import QLocale
+from pymodaq.daq_utils.qvariant import QVariant
 
 python_version = f'{str(sys.version_info.major)}.{str(sys.version_info.minor)}'
 if version_mod.parse(python_version) >= version_mod.parse('3.8'):  # from version 3.8 this feature is included in the
@@ -9,68 +32,97 @@ if version_mod.parse(python_version) >= version_mod.parse('3.8'):  # from versio
     from importlib import metadata
 else:
     import importlib_metadata as metadata  # pragma: no cover
-import pkgutil
 
-import traceback
-from collections import OrderedDict
+from pymodaq.daq_utils.exceptions import DataSourceError
 
-import numpy as np
-import datetime
-from pathlib import Path
-from ctypes import CFUNCTYPE
 
-if 'win32' in sys.platform:
-    from ctypes import WINFUNCTYPE
-
-import enum
-import os
-
-import importlib
-import toml
-import logging
-from logging.handlers import TimedRotatingFileHandler
-import inspect
-import json
-
-plot_colors = [(255, 0, 0), (0, 255, 0), (0, 0, 255), (14, 207, 189), (207, 14, 166), (207, 204, 14)]
+plot_colors = [(255, 255, 255), (255, 0, 0), (0, 255, 0), (0, 0, 255), (14, 207, 189), (207, 14, 166), (207, 204, 14)]
+config = Config()
 
 Cb = 1.602176e-19  # coulomb
 h = 6.626068e-34  # J.s
 c = 2.997924586e8  # m.s-1
 
 
+DATASOURCES = ('raw', 'roi')
+DATADIMS = ('Data0D', 'Data1D', 'Data2D', 'DataND')
+
+
+def load_config():
+    deprecation_msg(f'Configuration file must now be  imported from the pymodaq.daq_utils.messenger module')
+    return Config()
+
+
+def is_64bits():
+    return sys.maxsize > 2**32
+
+
+def timer(func):
+    """Print the runtime of the decorated function"""
+    @functools.wraps(func)
+    def wrapper_timer(*args, **kwargs):
+        start_time = time.perf_counter()    # 1
+        value = func(*args, **kwargs)
+        end_time = time.perf_counter()      # 2
+        run_time = end_time - start_time    # 3
+        print(f"Finished {func.__name__!r} in {run_time:.4f} secs")
+        return value
+    return wrapper_timer
+
+
+def set_logger(logger_name, add_handler=False, base_logger=False, add_to_console=False, log_level=None):
+    """defines a logger of a given name and eventually add an handler to it
+
+    Parameters
+    ----------
+    logger_name: (str) the name of the logger (usually it is the module name as returned by get_module_name
+    add_handler (bool) if True adds a TimedRotatingFileHandler to the logger instance (should be True if logger set from
+                main app
+    base_logger: (bool) specify if this is the parent logger (usually where one defines the handler)
+
+    Returns
+    -------
+    logger: (logging.logger) logger instance
+    See Also
+    --------
+    get_module_name, logging.handlers.TimedRotatingFileHandler
+    """
+    if not base_logger:
+        logger_name = f'pymodaq.{logger_name}'
+
+    logger = logging.getLogger(logger_name)
+    log_path = get_set_config_path('log')
+    if add_handler:
+        if log_level is None:
+            log_level = config('general', 'debug_level')
+        logger.setLevel(log_level)
+        handler = TimedRotatingFileHandler(log_path.joinpath('pymodaq.log'), when='midnight')
+        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+        handler.setFormatter(formatter)
+        logger.addHandler(handler)
+
+        logging.captureWarnings(True)
+        warnings.filterwarnings('default', category=DeprecationWarning)
+        warnings_logger = logging.getLogger("py.warnings")
+        warnings_logger.addHandler(handler)
+
+    if add_to_console:
+        console_handler = logging.StreamHandler()
+        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
+        console_handler.setFormatter(formatter)
+        logger.addHandler(console_handler)
+    return logger
+
+
+logger = set_logger('daq_utils')
+
+
 def get_version():
     with open(str(Path(__file__).parent.parent.joinpath('resources/VERSION')), 'r') as fvers:
         version = fvers.read().strip()
     return version
 
 
-def get_set_local_dir(basename='pymodaq_local'):
-    """Defines, creates abd returns a local folder where configurations files will be saved
-
-    Parameters
-    ----------
-    basename: (str) how the configuration folder will be named
-
-    Returns
-    -------
-    Path: the local path
-    """
-    local_path = Path.home().joinpath(basename)
-
-    if not local_path.is_dir():                            # pragma: no cover
-        try:
-            local_path.mkdir()
-        except Exception as e:
-            local_path = Path(__file__).parent.parent.joinpath(basename)
-            info = f"Cannot create local folder from your **Home** defined location: {Path.home()}," \
-                   f" using PyMoDAQ's folder as local directory: {local_path}"
-            print(info)
-            if not local_path.is_dir():
-                local_path.mkdir()
-    return local_path
-
-
 def copy_preset():                          # pragma: no cover
     path = get_set_preset_path().joinpath('preset_default.xml')
     if not path.exists():  # copy the preset_default from pymodaq folder and create one in pymodad's local folder
@@ -78,33 +130,26 @@ def copy_preset():                          # pragma: no cover
             path.write_text(file.read())
 
 
-def load_config(config_path=None):          # pragma: no cover
-    if not config_path:
-        config_path = get_set_local_dir().joinpath('config.toml')
-    config_base = toml.load(Path(__file__).parent.parent.joinpath('resources/config_template.toml'))
-    if not config_path.exists():  # copy the template from pymodaq folder and create one in pymodad's local folder
-        config_path.write_text(toml.dumps(config_base))
+def set_qt_backend():
+    backend_present = True
+    if config('qtbackend', 'backend').lower() not in [mod.lower() for mod in sys.modules]:
+        backend_present = False
+        logger.warning(f"The chosen Qt backend ({config('qtbackend', 'backend')}) has not been installed...\n"
+                       f"Trying another...")
+        backends = config('qtbackend', 'backends')
+        backends.pop(config('qtbackend', 'backend'))
+        for backend in backends:
+            if backend.lower() in [mod.lower() for mod in sys.modules]:
+                backend_present = True
+                break
 
-    # check if all fields are there
-    config = toml.load(config_path)
-    if check_config(config_base, config):
-        config_path.write_text(toml.dumps(config))
-    return config
-
-
-def check_config(config_base, config_local):
-    status = False
-    for key in config_base:
-        if key in config_local:
-            if isinstance(config_base[key], dict):
-                status = status or check_config(config_base[key], config_local[key])
-        else:
-            config_local[key] = config_base[key]
-            status = True
-    return status
-
-
-config = load_config()
+    if backend_present:
+        os.environ['QT_API'] = config('qtbackend', 'backend')
+        logger.info('************************')
+        logger.info(f"{config('qtbackend', 'backend')} Qt backend loaded")
+        logger.info('************************')
+    else:
+        logger.critical(f"No Qt backend could be found in your system, plese install either pyqt5/6 or pyside2/6")
 
 
 class JsonConverter:
@@ -163,7 +208,9 @@ def decode_data(encoded_data):
         item = {}
         for ind in range(map_items):
             key = ds.readInt32()
+            #TODO check this is fine
             value = QVariant()
+            #value = None
             ds >> value
             item[QtCore.Qt.ItemDataRole(key)] = value.value()
         data.append(item)
@@ -474,7 +521,41 @@ class ThreadCommand(object):
         self.attributes = attributes
 
 
-class Axis(dict):
+class AxisBase(dict):
+    """
+    Utility class defining an axis for pymodaq's viewers, attributes can be accessed as dictionary keys or class
+    type attributes
+    """
+
+    def __init__(self, label='', units='', **kwargs):
+        """
+
+        Parameters
+        ----------
+        data
+        label
+        units
+        """
+        if units is None:
+            units = ''
+        if label is None:
+            label = ''
+        if not isinstance(label, str):
+            raise TypeError('label for the Axis class should be a string')
+        self['label'] = label
+        if not isinstance(units, str):
+            raise TypeError('units for the Axis class should be a string')
+        self['units'] = units
+        self.update(kwargs)
+
+    def __getattr__(self, item):
+        if item in self:
+            return self[item]
+        else:
+            raise AttributeError(f'{item} is not a valid attribute')
+
+
+class Axis(AxisBase):
     """
     Utility class defining an axis for pymodaq's viewers, attributes can be accessed as dictionary keys
     """
@@ -488,21 +569,11 @@ class Axis(dict):
         label
         units
         """
-        if units is None:
-            units = ''
-        if label is None:
-            label = ''
-
+        super().__init__(label=label, units=units, **kwargs)
         if data is None or isinstance(data, np.ndarray):
             self['data'] = data
         else:
             raise TypeError('data for the Axis class should be a ndarray')
-        if not isinstance(label, str):
-            raise TypeError('label for the Axis class should be a string')
-        self['label'] = label
-        if not isinstance(units, str):
-            raise TypeError('units for the Axis class should be a string')
-        self['units'] = units
         self.update(kwargs)
 
 
@@ -516,6 +587,27 @@ class NavAxis(Axis):
         self['nav_index'] = nav_index
 
 
+class ScaledAxis(AxisBase):
+    def __init__(self, label='', units='', offset=0, scaling=1):
+        super().__init__(label=label, units=units)
+        if not (isinstance(offset, float) or isinstance(offset, int)):
+            raise TypeError('offset for the ScalingAxis class should be a float (or int)')
+        self['offset'] = offset
+        if not (isinstance(scaling, float) or isinstance(scaling, int)):
+            raise TypeError('scaling for the ScalingAxis class should be a non null float (or int)')
+        if scaling == 0 or scaling == 0.:
+            raise ValueError('scaling for the ScalingAxis class should be a non null float (or int)')
+        self['scaling'] = scaling
+
+
+class ScalingOptions(dict):
+    def __init__(self, scaled_xaxis: ScaledAxis, scaled_yaxis: ScaledAxis):
+        assert isinstance(scaled_xaxis, ScaledAxis)
+        assert isinstance(scaled_yaxis, ScaledAxis)
+        self['scaled_xaxis'] = scaled_xaxis
+        self['scaled_yaxis'] = scaled_yaxis
+
+
 class Data(OrderedDict):
     def __init__(self, name='', source='raw', distribution='uniform', x_axis=Axis(), y_axis=Axis(), **kwargs):
         """
@@ -525,32 +617,32 @@ class Data(OrderedDict):
         ----------
         source: (str) either 'raw' or 'roi...' if straight from a plugin or data processed within a viewer
         distribution: (str) either 'uniform' or 'spread'
-        x_axis: (Axis) Axis class defining the corresponding axis (with data either linearly spaced or containing the
+        x_axis: (Axis) Axis class defining the corresponding axis (if any) (with data either linearly spaced or containing the
          x positions of the spread points)
-        y_axis: (Axis) Axis class defining the corresponding axis (with data either linearly spaced or containing the
+        y_axis: (Axis) Axis class defining the corresponding axis (if any) (with data either linearly spaced or containing the
          x positions of the spread points)
         """
 
         if not isinstance(name, str):
-            raise TypeError('name for the DataToExport class should be a string')
+            raise TypeError(f'name for the {self.__class__.__name__} class should be a string')
         self['name'] = name
         if not isinstance(source, str):
-            raise TypeError('source for the DataToExport class should be a string')
+            raise TypeError(f'source for the {self.__class__.__name__} class should be a string')
         elif not ('raw' in source or 'roi' in source):
-            raise ValueError('Invalid "source" for the DataToExport class')
+            raise ValueError(f'Invalid "source" for the {self.__class__.__name__} class')
         self['source'] = source
 
         if not isinstance(distribution, str):
-            raise TypeError('distribution for the DataToExport class should be a string')
+            raise TypeError(f'distribution for the {self.__class__.__name__} class should be a string')
         elif distribution not in ('uniform', 'spread'):
-            raise ValueError('Invalid "distribution" for the DataToExport class')
+            raise ValueError(f'Invalid "distribution" for the {self.__class__.__name__} class')
         self['distribution'] = distribution
 
         if not isinstance(x_axis, Axis):
             if isinstance(x_axis, np.ndarray):
                 x_axis = Axis(data=x_axis)
             else:
-                raise TypeError('x_axis for the DataToExport class should be a Axis class')
+                raise TypeError(f'x_axis for the {self.__class__.__name__} class should be a Axis class')
             self['x_axis'] = x_axis
         elif x_axis['data'] is not None:
             self['x_axis'] = x_axis
@@ -559,7 +651,7 @@ class Data(OrderedDict):
             if isinstance(y_axis, np.ndarray):
                 y_axis = Axis(data=y_axis)
             else:
-                raise TypeError('y_axis for the DataToExport class should be a Axis class')
+                raise TypeError(f'y_axis for the {self.__class__.__name__} class should be a Axis class')
             self['y_axis'] = y_axis
         elif y_axis['data'] is not None:
             self['y_axis'] = y_axis
@@ -567,6 +659,15 @@ class Data(OrderedDict):
         for k in kwargs:
             self[k] = kwargs[k]
 
+    def __getattr__(self, name):
+        if name in self:
+            return self[name]
+        else:
+            raise AttributeError(f'{name} if not a key of {self}')
+
+    def __repr__(self):
+        return f'{self.__class__.__name__}: <name: {self.name}> - <distribution: {self.distribution}> - <source: {self.source}>'
+
 
 class DataFromPlugins(Data):
 
@@ -575,8 +676,6 @@ class DataFromPlugins(Data):
         Parameters
         ----------
         dim: (str) data dimensionality (either Data0D, Data1D, Data2D or DataND)
-
-
         """
         super().__init__(**kwargs)
         self['labels'] = labels
@@ -601,7 +700,7 @@ class DataFromPlugins(Data):
         else:
             raise TypeError('data for the DataFromPlugins class should be None or a list of numpy arrays')
 
-        if dim not in ('Data0D', 'Data1D', 'Data2D', 'DataND') and data is not None:
+        if dim not in DATADIMS and data is not None:
             ndim = len(data[0].shape)
             if ndim == 1:
                 if data[0].size == 1:
@@ -614,17 +713,22 @@ class DataFromPlugins(Data):
                 dim = 'DataND'
         self['dim'] = dim
 
+    def __repr__(self):
+        return f'{self.__class__.__name__}: <name: {self.name}> - <distribution: {self.distribution}>' \
+               f' - <source: {self.source}> - <dim: {self.dim}>'
+
 
 class DataToExport(Data):
-    def __init__(self, data=None, dim='', **kwargs):
+    def __init__(self, data=None, dim='', source='raw', **kwargs):
         """
         Utility class defining a data being exported from pymodaq's viewers, attributes can be accessed as dictionary keys
         Parameters
         ----------
         data: (ndarray or a scalar)
         dim: (str) data dimensionality (either Data0D, Data1D, Data2D or DataND)
+        source: (str) either 'raw' for raw data or 'roi' for data extracted from a roi
         """
-        super().__init__(**kwargs)
+        super().__init__(source=source, **kwargs)
         if data is None or isinstance(data, np.ndarray) or isinstance(data, float) or isinstance(data, int):
             self['data'] = data
         else:
@@ -645,27 +749,22 @@ class DataToExport(Data):
             else:
                 dim = 'Data0D'
         self['dim'] = dim
+        if source not in DATASOURCES:
+            raise DataSourceError(f'Data source should be in {DATASOURCES}')
+
+    def __repr__(self):
+        return f'{self.__class__.__name__}: <name: {self.name}> - <distribution: {self.distribution}>' \
+               f' - <source: {self.source}> - <dim: {self.dim}>'
 
 
-class ScaledAxis(Axis):
-    def __init__(self, label='', units='', offset=0, scaling=1):
-        super().__init__(label=label, units=units)
-        if not (isinstance(offset, float) or isinstance(offset, int)):
-            raise TypeError('offset for the ScalingAxis class should be a float (or int)')
-        self['offset'] = offset
-        if not (isinstance(scaling, float) or isinstance(scaling, int)):
-            raise TypeError('scaling for the ScalingAxis class should be a non null float (or int)')
-        if scaling == 0 or scaling == 0.:
-            raise ValueError('scaling for the ScalingAxis class should be a non null float (or int)')
-        self['scaling'] = scaling
-
-
-class ScalingOptions(dict):
-    def __init__(self, scaled_xaxis=ScaledAxis(), scaled_yaxis=ScaledAxis()):
-        assert isinstance(scaled_xaxis, ScaledAxis)
-        assert isinstance(scaled_yaxis, ScaledAxis)
-        self['scaled_xaxis'] = scaled_xaxis
-        self['scaled_yaxis'] = scaled_yaxis
+def setLocale():
+    """
+    defines the Locale to use to convert numbers to strings representation using language/country conventions
+    Default is English and US
+    """
+    language = getattr(QLocale, config('style', 'language'))
+    country = getattr(QLocale, config('style', 'country'))
+    QLocale.setDefault(QLocale(language, country))
 
 
 def recursive_find_files_extension(ini_path, ext, paths=[]):
@@ -678,23 +777,68 @@ def recursive_find_files_extension(ini_path, ext, paths=[]):
     return paths
 
 
+def recursive_find_files(ini_path, exp='make_enum', paths=[],
+                         filters=['build']):
+    for child in Path(ini_path).iterdir():
+        if child.is_dir():
+            recursive_find_files(child, exp, paths, filters)
+        else:
+            if exp in child.stem:
+                if not any([filt in str(child) for filt in filters]):
+                    paths.append(child)
+    return paths
+
+
 def recursive_find_expr_in_files(ini_path, exp='make_enum', paths=[],
-                                 filters=['.git', '.idea', '__pycache__', 'build', 'egg', 'documentation', '.tox']):
+                                 filters=['.git', '.idea', '__pycache__', 'build', 'egg', 'documentation', '.tox'],
+                                 replace=False, replace_str=''):
+
     for child in Path(ini_path).iterdir():
         if not any(filt in str(child) for filt in filters):
             if child.is_dir():
-                recursive_find_expr_in_files(child, exp, paths, filters)
+                recursive_find_expr_in_files(child, exp, paths, filters, replace=replace, replace_str=replace_str)
             else:
                 try:
+                    found = False
                     with child.open('r') as f:
-                        for ind, line in enumerate(f.readlines()):
+                        replacement = ''
+                        for ind, line in enumerate(f):
                             if exp in line:
-                                paths.append([child, ind])
+                                found = True
+                                paths.append([child, ind, line])
+                                if replace:
+                                    replacement += line.replace(exp, replace_str)
+                            else:
+                                if replace:
+                                    replacement += line
+                    if replace and found:
+                        with child.open('w') as f:
+                            f.write(replacement)
                 except Exception:
                     pass
     return paths
 
 
+def count_lines(ini_path, count=0, filters=['lextab', 'yacctab','pycache', 'pyc']):
+    # if Path(ini_path).is_file():
+    #     with Path(ini_path).open('r') as f:
+    #         count += len(f.readlines())
+    #     return count
+    for child in Path(ini_path).iterdir():
+        if child.is_dir():
+            count = count_lines(child, count)
+        else:
+            try:
+                if not any([filt in child.name for filt in filters]):
+                    if '.py' in child.name:
+                        with child.open('r') as f:
+                            count += len(f.readlines())
+                else:
+                    print(child.stem)
+            except Exception:
+                pass
+    return count
+
 def remove_spaces(string):
     """
     return a string without any white spaces in it
@@ -763,6 +907,117 @@ def elt_as_first_element_dicts(elt_list, match_word='Mock', key='name'):
     return plugins
 
 
+def get_extensions():
+    """
+    Get pymodaq extensions as a list
+
+    Returns
+    -------
+    list: list of disct containting the name and module of the found extension
+    """
+    extension_import = []
+    entry_points = metadata.entry_points()
+    if 'pymodaq.extensions' in entry_points:
+        discovered_extension = entry_points['pymodaq.extensions']
+
+        for pkg in discovered_extension:
+            try:
+                module = importlib.import_module(pkg.value)
+                if hasattr(module, 'NICE_NAME'):
+                    name = module.NICE_NAME
+                else:
+                    name = pkg.value
+                extension = {'name': name, 'module': module}
+                extension_import.append(extension)
+
+            except Exception as e:  # pragma: no cover
+                logger.warning(f'Impossible to import the {pkg.value} extension: {str(e)}')
+
+    return extension_import
+
+def find_dict_if_matched_key_val(dict_tmp, key, value):
+    """
+    check if a key/value pair match in a given dictionnary
+    Parameters
+    ----------
+    dict_tmp: (dict) the dictionnary to be tested
+    key: (str) a key string to look for in dict_tmp
+    value: (object) any python object
+
+    Returns
+    -------
+    bool: True if the key/value pair has been found in dict_tmp
+
+    """
+    if key in dict_tmp:
+        if dict_tmp[key] == value:
+            return True
+    return False
+
+
+def find_dict_in_list_from_key_val(dicts, key, value, return_index=False):
+    """ lookup within a list of dicts. Look for the dict within the list which has the correct key, value pair
+
+    Parameters
+    ----------
+    dicts: (list) list of dictionnaries
+    key: (str) specific key to look for in each dict
+    value: value to match
+
+    Returns
+    -------
+    dict: if found otherwise returns None
+    """
+    for ind, dict_tmp in enumerate(dicts):
+        if find_dict_if_matched_key_val(dict_tmp, key, value):
+            if return_index:
+                return dict_tmp, ind
+            else:
+                return dict_tmp
+    if return_index:
+        return None, -1
+    else:
+        return None
+
+
+def get_models(model_name=None):
+    """
+    Get PID Models as a list to instantiate Control Actuators per degree of liberty in the model
+
+    Returns
+    -------
+    list: list of disct containting the name and python module of the found models
+    """
+    from pymodaq.pid.utils import PIDModelGeneric
+    models_import = []
+    entry_points = metadata.entry_points()
+    if 'pymodaq.pid_models' in entry_points:
+        discovered_models = entry_points['pymodaq.pid_models']
+        for pkg in discovered_models:
+            try:
+                module = importlib.import_module(pkg.value)
+                module_name = pkg.value
+
+                for mod in pkgutil.iter_modules([str(Path(module.__file__).parent.joinpath('models'))]):
+                    try:
+                        model_module = importlib.import_module(f'{module_name}.models.{mod.name}', module)
+                        classes = inspect.getmembers(model_module, inspect.isclass)
+                        for name, klass in classes:
+                            if klass.__base__ is PIDModelGeneric:
+                                models_import.append({'name': mod.name, 'module': model_module, 'class': klass})
+                                break
+
+                    except Exception as e:  # pragma: no cover
+                        logger.warning(str(e))
+
+            except Exception as e:  # pragma: no cover
+                logger.warning(f'Impossible to import the {pkg.value} extension: {str(e)}')
+
+    if model_name is None:
+        return models_import
+    else:
+        return find_dict_in_list_from_key_val(models_import, 'name', model_name)
+
 def get_plugins(plugin_type='daq_0Dviewer'):  # pragma: no cover
     """
     Get plugins names as a list
@@ -802,6 +1057,17 @@ def get_plugins(plugin_type='daq_0Dviewer'):  # pragma: no cover
                     pass
         except Exception:  # pragma: no cover
             pass
+
+    #add utility plugin for PID
+    if plugin_type == 'daq_move':
+        try:
+            submodule = importlib.import_module('pymodaq.pid')
+
+            plugins_import.append({'name': 'PID', 'module': submodule})
+
+        except Exception:  # pragma: no cover
+            pass
+
     plugins_import = elt_as_first_element_dicts(plugins_import, match_word='Mock', key='name')
     return plugins_import
 
@@ -814,119 +1080,12 @@ def check_vals_in_iterable(iterable1, iterable2):
         assert val1 == val2
 
 
-def get_set_config_path(config_name='config'):
-    """Creates a folder in the local config directory to store specific configuration files
-
-    Parameters
-    ----------
-    config_name: (str) name of the configuration folder
-
-    Returns
-    -------
-
-    See Also
-    --------
-    get_set_local_dir
-    """
-    local_path = get_set_local_dir()
-    path = local_path.joinpath(config_name)
-    if not path.is_dir():
-        path.mkdir()  # pragma: no cover
-    return path
-
-
-def get_set_preset_path():
-    """ creates and return the config folder path for managers files
-    """
-    return get_set_config_path('preset_configs')
-
-def get_set_batch_path():
-    """ creates and return the config folder path for managers files
-    """
-    return get_set_config_path('batch_configs')
-
-
-def get_set_pid_path():
-    """ creates and return the config folder path for PID files
-    """
-    return get_set_config_path('pid_configs')
-
-
-def get_set_log_path():
-    """ creates and return the config folder path for log files
-    """
-    return get_set_config_path('log')
-
-
-def get_set_layout_path():
-    """ creates and return the config folder path for layout files
-    """
-    return get_set_config_path('layout_configs')
-
-
-def get_set_remote_path():
-    """ creates and return the config folder path for remote (shortcuts or joystick) files
-    """
-    return get_set_config_path('remote_configs')
-
-
-def get_set_overshoot_path():
-    """ creates and return the config folder path for overshoot files
-    """
-    return get_set_config_path('overshoot_configs')
-
-
-def get_set_roi_path():
-    """ creates and return the config folder path for managers files
-    """
-    return get_set_config_path('roi_configs')
-
-
 def get_module_name(module__file__path):
     """from the full path of a module extract its name"""
     path = Path(module__file__path)
     return path.stem
 
 
-def set_logger(logger_name, add_handler=False, base_logger=False, add_to_console=False, log_level=None):
-    """defines a logger of a given name and eventually add an handler to it
-
-    Parameters
-    ----------
-    logger_name: (str) the name of the logger (usually it is the module name as returned by get_module_name
-    add_handler (bool) if True adds a TimedRotatingFileHandler to the logger instance (should be True if logger set from
-                main app
-    base_logger: (bool) specify if this is the parent logger (usually where one defines the handler)
-
-    Returns
-    -------
-    logger: (logging.logger) logger instance
-    See Also
-    --------
-    get_module_name, logging.handlers.TimedRotatingFileHandler
-    """
-    if not base_logger:
-        logger_name = f'pymodaq.{logger_name}'
-
-    logger = logging.getLogger(logger_name)
-    log_path = get_set_config_path('log')
-    if add_handler:
-        if log_level is None:
-            config = load_config()
-            log_level = config['general']['debug_level']
-        logger.setLevel(log_level)
-        handler = TimedRotatingFileHandler(log_path.joinpath('pymodaq.log'), when='midnight')
-        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
-        handler.setFormatter(formatter)
-        logger.addHandler(handler)
-    if add_to_console:
-        console_handler = logging.StreamHandler()
-        formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
-        console_handler.setFormatter(formatter)
-        logger.addHandler(console_handler)
-    return logger
-
-
 def caller_name(skip=2):
     """Get a name of a caller in the format module.class.method
 
@@ -1060,7 +1219,7 @@ def set_param_from_param(param_old, param_new):
 # ########################
 # #File management
 
-def get_new_file_name(base_path=Path(config['data_saving']['h5file']['save_path']), base_name='tttr_data'):
+def get_new_file_name(base_path=Path(config('data_saving', 'h5file', 'save_path')), base_name='tttr_data'):
     if isinstance(base_path, str):
         base_path = Path(base_path)
 
@@ -1198,49 +1357,9 @@ def linspace_step(start, stop, step):
     return np.linspace(start, new_stop, Nsteps)
 
 
-def find_dict_if_matched_key_val(dict_tmp, key, value):
-    """
-    check if a key/value pair match in a given dictionnary
-    Parameters
-    ----------
-    dict_tmp: (dict) the dictionnary to be tested
-    key: (str) a key string to look for in dict_tmp
-    value: (object) any python object
-
-    Returns
-    -------
-    bool: True if the key/value pair has been found in dict_tmp
-
-    """
-    if key in dict_tmp:
-        if dict_tmp[key] == value:
-            return True
-    return False
-
-
-def find_dict_in_list_from_key_val(dicts, key, value, return_index=False):
-    """ lookup within a list of dicts. Look for the dict within the list which has the correct key, value pair
-
-    Parameters
-    ----------
-    dicts: (list) list of dictionnaries
-    key: (str) specific key to look for in each dict
-    value: value to match
-
-    Returns
-    -------
-    dict: if found otherwise returns None
-    """
-    for ind, dict_tmp in enumerate(dicts):
-        if find_dict_if_matched_key_val(dict_tmp, key, value):
-            if return_index:
-                return dict_tmp, ind
-            else:
-                return dict_tmp
-    if return_index:
-        return None, -1
-    else:
-        return None
+def linspace_step_N(start, step, Npts):
+    stop = (Npts - 1) * step + start
+    return linspace_step(start, stop, step)
 
 
 def find_index(x, threshold):
@@ -1356,9 +1475,7 @@ def gauss2D(x, x0, dx, y, y0, dy, n=1, angle=0):
         for indx, xtmp in enumerate(x):
             for indy, ytmp in enumerate(y):
                 rotatedvect = R.dot(np.array([xtmp, ytmp]))
-                data[indy, indx] = np.exp(
-                    -2 * np.log(2) ** (1 / n) * ((rotatedvect[0] - x0r) / dx) ** (2 * n)) * np.exp(
-                    -2 * np.log(2) ** (1 / n) * ((rotatedvect[1] - y0r) / dy) ** (2 * n))
+                data[indy, indx] = gauss1D(rotatedvect[0], x0r, dx, n) * gauss1D(rotatedvect[1], y0r, dy, n)
 
     return data
 
@@ -1537,10 +1654,39 @@ def ift2(x, dim=(-2, -1)):
 
 
 if __name__ == '__main__':
-    # paths = recursive_find_expr_in_files('C:\\Users\\weber\\Labo\\Programmes Python\\PyMoDAQ_Git', '__version__')
+    #paths = recursive_find_expr_in_files('C:\\Users\\weber\\Labo\\Programmes Python\\PyMoDAQ_Git', 'visa')
     # for p in paths:
     #     print(str(p))
     # v = get_version()
     # pass
-    plugins = get_plugins()  # pragma: no cover
+    #plugins = get_plugins()  # pragma: no cover
+    #extensions = get_extension()
+    #models = get_models()
+    #count = count_lines('C:\\Users\\weber\\Labo\\Programmes Python\\PyMoDAQ_Git\\pymodaq\src')
+
+
+    # import license
+    # mit = license.find('MIT')
+    #
+    paths = recursive_find_expr_in_files('C:\\Users\\weber\\Labo\\Programmes Python\\PyMoDAQ_Git',
+                                         exp='DAQmxTypes',
+                                         paths=[],
+                                         filters=['.git', '.idea', '__pycache__', 'build', 'egg', 'documentation',
+                                                  '.tox', 'daq_utils.py', '.rst'],
+                                         replace=False, replace_str="'limits'")
     pass
+    # paths = recursive_find_files('C:\\Users\\weber\\Labo\\Programmes Python\\PyMoDAQ_Git',
+    #                      exp='VERSION', paths=[])
+    # import version
+    # for file in paths:
+    #     with open(str(file), 'r') as f:
+    #         v = version.Version(f.read())
+    #         v.minor += 1
+    #         v.patch = 0
+    #     with open(str(file), 'w') as f:
+    #         f.write(str(v))
+
+    # for file in paths:
+    #     with open(str(file), 'w') as f:
+    #         f.write(mit.render(name='Sebastien Weber', email='sebastien.weber@cemes.fr'))
+
