@@ -1,17 +1,22 @@
 import logging
 import datetime
-from PyQt5 import QtCore
+
+from pymodaq.daq_utils.config import Config
+from qtpy import QtCore
 from contextlib import contextmanager
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 from sqlalchemy_utils import database_exists, create_database
-from .db_logger_models import Base, Data0D, Data1D, Data2D, LogInfo, Detector, Configuration
+from pymodaq.daq_utils.db.db_logger.db_logger_models import Base, Data0D, Data1D, Data2D, LogInfo, Detector, Configuration
 from pymodaq.daq_utils import daq_utils as utils
 from pymodaq.daq_utils.gui_utils import dashboard_submodules_params
+from pymodaq.daq_utils.messenger import messagebox
+from pymodaq.daq_utils.abstract.logger import AbstractLogger
 from pyqtgraph.parametertree import Parameter, ParameterTree
 
+
 logger = utils.set_logger(utils.get_module_name(__file__))
-config = utils.load_config()
+config = Config()
 
 
 class DBLogHandler(logging.StreamHandler):
@@ -27,11 +32,11 @@ class DBLogHandler(logging.StreamHandler):
 
 
 class DbLogger:
-    user = config['network']['logging']['user']['username']
-    user_pwd = config['network']['logging']['user']['pwd']
+    user = config('network', 'logging', 'user', 'username')
+    user_pwd = config('network', 'logging', 'user', 'pwd')
 
-    def __init__(self, database_name, ip_address=config['network']['logging']['sql']['ip'],
-                 port=config['network']['logging']['sql']['port'], save2D=False):
+    def __init__(self, database_name, ip_address=config('network', 'logging', 'sql', 'ip'),
+                 port=config('network', 'logging', 'sql', 'port'), save2D=False):
         """
 
         Parameters
@@ -72,8 +77,19 @@ class DbLogger:
             session.close()
 
     def connect_db(self):
-        self.engine = create_engine(f"postgresql://{self.user}:{self.user_pwd}@{self.ip_address}:"
-                                    f"{self.port}/{self.database_name}")
+        url = f"postgresql://{self.user}:{self.user_pwd}@{self.ip_address}:"\
+              f"{self.port}/{self.database_name}"
+        logger.debug(f'Connecting database using: {url}')
+        try:
+            self.engine = create_engine(f"postgresql://{self.user}:{self.user_pwd}@{self.ip_address}:"
+                                        f"{self.port}/{self.database_name}")
+        except ModuleNotFoundError as e:
+            messagebox('warning', 'ModuleError',
+                       f'The postgresql backend *psycopg2* has not been installed.\n'
+                       f'Could not connect to your database')
+            logger.warning(str(e))
+            return False
+
         try:
             if not database_exists(self.engine.url):
                 create_database(self.engine.url)
@@ -84,6 +100,7 @@ class DbLogger:
 
         self.create_table()
         self.Session = sessionmaker(bind=self.engine)
+        logger.debug(f'Database Connected')
         return True
 
     def close(self):
@@ -166,18 +183,19 @@ class DbLogger:
 class DbLoggerGUI(DbLogger, QtCore.QObject):
     params = [
         {'title': 'Database:', 'name': 'database_type', 'type': 'list', 'value': 'PostgreSQL',
-            'values': ['PostgreSQL', ]},
+            'limits': ['PostgreSQL', ]},
         {'title': 'Server IP:', 'name': 'server_ip', 'type': 'str',
-            'value': config['network']['logging']['sql']['ip']},
+            'value': config('network', 'logging', 'sql', 'ip'),
+         'tip':'Either localhost if the database server is on the same computer or the IP address of the server'},
         {'title': 'Server port:', 'name': 'server_port', 'type': 'int',
-            'value': config['network']['logging']['sql']['port']},
+            'value': config('network', 'logging', 'sql', 'port')},
         {'title': 'Connect:', 'name': 'connect_db', 'type': 'bool_push', 'value': False},
-        {'title': 'Connected:', 'name': 'connected_db', 'type': 'led', 'value': False, 'readonly': True},
+        {'title': 'Connected:', 'name': 'connected_db', 'type': 'led', 'value': False},
     ] + dashboard_submodules_params
 
     def __init__(self, database_name):
-        DbLogger.__init__(self, database_name, ip_address=config['network']['logging']['sql']['ip'],
-                          port=config['network']['logging']['sql']['port'], save2D=False)
+        DbLogger.__init__(self, database_name, ip_address=config('network', 'logging', 'sql', 'ip'),
+                          port=config('network', 'logging', 'sql', 'port'), save2D=False)
         QtCore.QObject.__init__(self)
 
         self.settings = Parameter.create(title='DB settings', name='db_settings', type='group',
@@ -216,11 +234,61 @@ class DbLoggerGUI(DbLogger, QtCore.QObject):
                     self.port = param.value()
 
                 elif param.name() == 'connect_db':
-                    status = self.connect_db()
-                    self.settings.child(('connected_db')).setValue(status)
+                    if param.value():
+                        status = self.connect_db()
+                        self.settings.child('connected_db').setValue(status)
+                    else:
+                        self.close()
+                        self.settings.child('connected_db').setValue(False)
 
                 elif param.name() == 'save_2D':
                     self.save2D = param.value()
 
             elif change == 'parent':
                 pass
+
+
+class DataBaseLogger(AbstractLogger):
+    def __init__(self, database_name):
+        self.dblogger = DbLoggerGUI(database_name)
+
+    @property
+    def settings_tree(self):
+        return self.dblogger.settings_tree
+
+    @property
+    def settings(self):
+        return self.dblogger.settings
+
+    def init_logger(self, settings):
+        if not self.settings.child('connected_db').value():
+            status = self.dblogger.connect_db()
+            if not status:
+                logger.critical('the Database is not and cannot be connnect')
+                return False
+
+        self.dblogger.add_config(settings)
+        return True
+
+    def get_handler(self):
+        return DBLogHandler(self.dblogger)
+
+    def add_detector(self, det_name, settings):
+        self.dblogger.add_detectors([dict(name=det_name, xml_settings=settings)])
+
+    def add_datas(self, datas):
+        self.dblogger.add_datas(datas)
+        self.settings.child(('N_saved')).setValue(
+            self.settings.child(('N_saved')).value() + 1)
+
+    def stop_logger(self):
+        pass
+
+    def close(self):
+        pass
+
+
+if __name__ == '__main__':
+    db = DbLogger('preset_default')
+    db.connect_db()
+    pass
\ No newline at end of file
