@@ -1,8 +1,9 @@
 import sys
 from collections import OrderedDict
 import numpy as np
-from PyQt5 import QtWidgets, QtCore
-from PyQt5.QtCore import QObject, pyqtSignal, QLocale, pyqtSlot
+from pymodaq.daq_utils.config import Config
+from qtpy import QtWidgets, QtCore
+from qtpy.QtCore import QObject, Signal, Slot
 
 from pymodaq.daq_utils.parameter import ioxml
 
@@ -11,20 +12,24 @@ from pymodaq.daq_utils.plotting.scan_selector import ScanSelector
 import pymodaq.daq_utils.daq_utils as utils
 import pymodaq.daq_utils.gui_utils as gutils
 from pymodaq.daq_utils.parameter import utils as putils
-from pymodaq.daq_utils.plotting.plot_utils import QVector
+from pymodaq.daq_utils.plotting.utils.plot_utils import QVector
 from pyqtgraph.parametertree import Parameter, ParameterTree
 import pymodaq.daq_utils.parameter.pymodaq_ptypes as pymodaq_types  # to be placed after importing Parameter
 
 from pymodaq.daq_utils.exceptions import ScannerException
 
 logger = utils.set_logger(utils.get_module_name(__file__))
-config = utils.load_config()
+config = Config()
 
-scan_types = ['Scan1D', 'Scan2D', 'Sequential', 'Tabular']
-scan_subtypes = dict(Scan1D=['Linear', 'Adaptive', 'Linear back to start', 'Random'],
-                     Scan2D=['Spiral', 'Linear', 'Adaptive', 'Back&Forth', 'Random'],
-                     Sequential=['Linear'],
-                     Tabular=['Linear', 'Adaptive'])
+SCAN_TYPES = ['Scan1D', 'Scan2D', 'Sequential', 'Tabular']
+SCAN_SUBTYPES = dict(Scan1D=dict(subpath=('scan1D_settings', 'scan1D_type'),
+                                 limits=['Linear', 'Adaptive', 'Linear back to start', 'Random']),
+                     Scan2D=dict(subpath=('scan2D_settings', 'scan2D_type'),
+                                 limits=['Spiral', 'Linear', 'Adaptive', 'Back&Forth', 'Random']),
+                     Sequential=dict(subpath=('seq_settings', 'scanseq_type'),
+                                     limits=['Linear']),
+                     Tabular=dict(subpath=('tabular_settings', 'tabular_subtype'),
+                                  limits=['Linear', 'Adaptive']))
 
 try:
     import adaptive
@@ -35,16 +40,14 @@ try:
         loss2D=['default', 'resolution', 'uniform', 'triangle'])
 
 except Exception:
-    scan_subtypes['Scan1D'].pop(scan_subtypes['Scan1D'].index('Adaptive'))
-    scan_subtypes['Scan2D'].pop(scan_subtypes['Scan2D'].index('Adaptive'))
-    scan_subtypes['Tabular'].pop(scan_subtypes['Tabular'].index('Adaptive'))
+    SCAN_SUBTYPES['Scan1D']['limits'].pop(SCAN_SUBTYPES['Scan1D']['limits'].index('Adaptive'))
+    SCAN_SUBTYPES['Scan2D']['limits'].pop(SCAN_SUBTYPES['Scan2D']['limits'].index('Adaptive'))
+    SCAN_SUBTYPES['Tabular']['limits'].pop(SCAN_SUBTYPES['Tabular']['limits'].index('Adaptive'))
     adaptive_losses = None
     adaptive = None
     logger.info('adaptive module is not present, no adaptive scan possible')
 
 
-
-
 class ScanInfo:
     def __init__(self, Nsteps=0, positions=None, axes_indexes=None, axes_unique=None, **kwargs):
         """
@@ -71,8 +74,6 @@ class ScanInfo:
             return '[ScanInfo with position is None)'
 
 
-
-
 class ScanParameters:
     """
     Utility class to define and store information about scans to be done
@@ -85,8 +86,8 @@ class ScanParameters:
         Parameters
         ----------
         Naxes: (int) number of axes used to do the scan
-        scan_type: (str) one value of the scan_types list items
-        scan_subtype: (str) ne value of the scan_subtypes dict items for the scan_type key
+        scan_type: (str) one value of the SCAN_TYPES list items
+        scan_subtype: (str) ne value of the SCAN_SUBTYPES dict items for the scan_type key
         starts: (list of floats) list of starts position of each axis
         stops: (list of floats) list of stops position of each axis
         steps: (list of floats) list of steps position of each axis
@@ -98,12 +99,13 @@ class ScanParameters:
         daq_utils.plotting.scan_selector
         """
         self.Naxes = Naxes
-        if scan_type not in scan_types:
+        if scan_type not in SCAN_TYPES:
             raise ValueError(
-                f'Chosen scan_type value ({scan_type}) is not possible. Should be among : {str(scan_types)}')
-        if scan_subtype not in scan_subtypes[scan_type]:
+                f'Chosen scan_type value ({scan_type}) is not possible. Should be among : {str(SCAN_TYPES)}')
+        if scan_subtype not in SCAN_SUBTYPES[scan_type]['limits']:
             raise ValueError(
-                f'Chosen scan_subtype value ({scan_subtype}) is not possible. Should be among : {str(scan_subtypes[scan_type])}')
+                f'Chosen scan_subtype value ({scan_subtype}) is not possible. Should be among'
+                f' : {str(SCAN_SUBTYPES[scan_type]["limits"])}')
         self.scan_type = scan_type
         self.scan_subtype = scan_subtype
         self.adaptive_loss = adaptive_loss
@@ -144,7 +146,7 @@ class ScanParameters:
             axes_unique = []
             for ax in positions.T:
                 axes_unique.append(np.unique(ax))
-            axes_indexes = np.zeros_like(positions, dtype=np.int)
+            axes_indexes = np.zeros_like(positions, dtype=int)
             for ind in range(positions.shape[0]):
                 for ind_pos, pos in enumerate(positions[ind]):
                     axes_indexes[ind, ind_pos] = utils.find_index(axes_unique[ind_pos], pos)[0][0]
@@ -155,7 +157,7 @@ class ScanParameters:
             return ScanInfo()
 
     def set_scan(self):
-        steps_limit = config['scan']['steps_limit']
+        steps_limit = config('scan', 'steps_limit')
         Nsteps = self.evaluate_Nsteps()
         if Nsteps > steps_limit:
             self.scan_info = ScanInfo(Nsteps=Nsteps)
@@ -187,8 +189,9 @@ class ScanParameters:
                 raise ScannerException(f'The chosen scan_subtype: {str(self.scan_subtype)} is not known')
 
         elif self.scan_type == "Scan2D":
-            if np.abs((self.stops[0]-self.starts[0]) / self.steps[0]) > steps_limit:
-                return ScanInfo()
+            if self.scan_subtype != 'Adaptive':
+                if np.abs((self.stops[0]-self.starts[0]) / self.steps[0]) > steps_limit:
+                    return ScanInfo()
 
             if self.scan_subtype == 'Spiral':
                 positions = set_scan_spiral(self.starts, self.stops, self.steps)
@@ -248,7 +251,9 @@ class ScanParameters:
         Nsteps = 1
         if self.starts is not None:
             for ind in range(len(self.starts)):
-                if self.scan_subtype != 'Spiral':
+                if self.scan_subtype == 'Adaptive':
+                    Nsteps = 1
+                elif self.scan_subtype != 'Spiral':
                     Nsteps *= np.abs((self.stops[ind] - self.starts[ind]) / self.steps[ind])+1
                 else:
                     Nsteps *= np.abs(2 * (self.stops[ind] / self.steps[ind]) + 1)
@@ -267,75 +272,75 @@ class ScanParameters:
 
 
 class Scanner(QObject):
-    scan_params_signal = pyqtSignal(ScanParameters)
+    scan_params_signal = Signal(ScanParameters)
 
     params = [#{'title': 'Scanner settings', 'name': 'scan_options', 'type': 'group', 'children': [
         {'title': 'Calculate positions:', 'name': 'calculate_positions', 'type': 'action'},
         {'title': 'N steps:', 'name': 'Nsteps', 'type': 'int', 'value': 0, 'readonly': True},
 
-        {'title': 'Scan type:', 'name': 'scan_type', 'type': 'list', 'values': scan_types,
-         'value': config['scan']['default']},
+        {'title': 'Scan type:', 'name': 'scan_type', 'type': 'list', 'limits': SCAN_TYPES,
+         'value': config('scan', 'default')},
         {'title': 'Scan1D settings', 'name': 'scan1D_settings', 'type': 'group', 'children': [
             {'title': 'Scan subtype:', 'name': 'scan1D_type', 'type': 'list',
-             'values': scan_subtypes['Scan1D'], 'value': config['scan']['scan1D']['type'],
+             'limits': SCAN_SUBTYPES['Scan1D']['limits'], 'value': config('scan', 'scan1D', 'type'),
              'tip': 'For adaptive, an algo will '
                     'determine the positions to check within the scan bounds. The defined step will be set as the'
                     'biggest feature size the algo should reach.'},
             {'title': 'Loss type', 'name': 'scan1D_loss', 'type': 'list',
-             'values': [], 'tip': 'Type of loss used by the algo. to determine next points'},
-            {'title': 'Start:', 'name': 'start_1D', 'type': 'float', 'value': config['scan']['scan1D']['start']},
-            {'title': 'stop:', 'name': 'stop_1D', 'type': 'float', 'value': config['scan']['scan1D']['stop']},
-            {'title': 'Step:', 'name': 'step_1D', 'type': 'float', 'value': config['scan']['scan1D']['step']}
+             'limits': [], 'tip': 'Type of loss used by the algo. to determine next points'},
+            {'title': 'Start:', 'name': 'start_1D', 'type': 'float', 'value': config('scan', 'scan1D', 'start')},
+            {'title': 'stop:', 'name': 'stop_1D', 'type': 'float', 'value': config('scan', 'scan1D', 'stop')},
+            {'title': 'Step:', 'name': 'step_1D', 'type': 'float', 'value': config('scan', 'scan1D', 'step')}
         ]},
         {'title': 'Scan2D settings', 'name': 'scan2D_settings', 'type': 'group', 'visible': False, 'children': [
             {'title': 'Scan subtype:', 'name': 'scan2D_type', 'type': 'list',
-             'values': scan_subtypes['Scan2D'], 'value': config['scan']['scan2D']['type'],
+             'limits': SCAN_SUBTYPES['Scan2D']['limits'], 'value': config('scan', 'scan2D', 'type'),
              'tip': 'For adaptive, an algo will '
                     'determine the positions to check within the scan bounds. The defined step will be set as the'
                     'biggest feature size the algo should reach.'},
             {'title': 'Loss type', 'name': 'scan2D_loss', 'type': 'list',
-             'values': [], 'tip': 'Type of loss used by the algo. to determine next points'},
-            {'title': 'Selection:', 'name': 'scan2D_selection', 'type': 'list', 'values': ['Manual', 'FromROI']},
-            {'title': 'From module:', 'name': 'scan2D_roi_module', 'type': 'list', 'values': [], 'visible': False},
+             'limits': [], 'tip': 'Type of loss used by the algo. to determine next points'},
+            {'title': 'Selection:', 'name': 'scan2D_selection', 'type': 'list', 'limits': ['Manual', 'FromROI']},
+            {'title': 'From module:', 'name': 'scan2D_roi_module', 'type': 'list', 'limits': [], 'visible': False},
             {'title': 'Start Ax1:', 'name': 'start_2d_axis1', 'type': 'float',
-             'value': config['scan']['scan2D']['start1'], 'visible': True},
+             'value': config('scan', 'scan2D', 'start1'), 'visible': True},
             {'title': 'Start Ax2:', 'name': 'start_2d_axis2', 'type': 'float',
-             'value': config['scan']['scan2D']['start2'], 'visible': True},
+             'value': config('scan', 'scan2D', 'start2'), 'visible': True},
             {'title': 'Step Ax1:', 'name': 'step_2d_axis1', 'type': 'float',
-             'value': config['scan']['scan2D']['step1'], 'visible': True},
+             'value': config('scan', 'scan2D', 'step1'), 'visible': True},
             {'title': 'Step Ax2:', 'name': 'step_2d_axis2', 'type': 'float',
-             'value': config['scan']['scan2D']['step2'], 'visible': True},
+             'value': config('scan', 'scan2D', 'step2'), 'visible': True},
             {'title': 'Npts/axis', 'name': 'npts_by_axis', 'type': 'int', 'min': 1,
-             'value': config['scan']['scan2D']['npts'],
+             'value': config('scan', 'scan2D', 'npts'),
              'visible': True},
             {'title': 'Stop Ax1:', 'name': 'stop_2d_axis1', 'type': 'float',
-             'value': config['scan']['scan2D']['stop1'], 'visible': True,
+             'value': config('scan', 'scan2D', 'stop1'), 'visible': True,
              'readonly': True, },
             {'title': 'Stop Ax2:', 'name': 'stop_2d_axis2', 'type': 'float',
-             'value': config['scan']['scan2D']['stop2'], 'visible': True,
+             'value': config('scan', 'scan2D', 'stop2'), 'visible': True,
              'readonly': True, },
 
         ]},
         {'title': 'Sequential settings', 'name': 'seq_settings', 'type': 'group', 'visible': False, 'children': [
             {'title': 'Scan subtype:', 'name': 'scanseq_type', 'type': 'list',
-             'values': scan_subtypes['Sequential'], 'value': scan_subtypes['Sequential'][0], },
+             'limits': SCAN_SUBTYPES['Sequential']['limits'], 'value': SCAN_SUBTYPES['Sequential']['limits'][0], },
             {'title': 'Sequences', 'name': 'seq_table', 'type': 'table_view',
              'delegate': gutils.SpinBoxDelegate},
         ]},
         {'title': 'Tabular settings', 'name': 'tabular_settings', 'type': 'group', 'visible': False, 'children': [
             {'title': 'Scan subtype:', 'name': 'tabular_subtype', 'type': 'list',
-             'values': scan_subtypes['Tabular'], 'value': config['scan']['tabular']['type'],
+             'limits': SCAN_SUBTYPES['Tabular']['limits'], 'value': config('scan', 'tabular', 'type'),
              'tip': 'For adaptive, an algo will '
                     'determine the positions to check within the scan bounds. The defined step will be set as the'
                     'biggest feature size the algo should reach.'},
             {'title': 'Loss type', 'name': 'tabular_loss', 'type': 'list',
-             'values': [], 'tip': 'Type of loss used by the algo. to determine next points'},
+             'limits': [], 'tip': 'Type of loss used by the algo. to determine next points'},
             {'title': 'Selection:', 'name': 'tabular_selection', 'type': 'list',
-             'values': ['Manual', 'Polylines']},
-            {'title': 'From module:', 'name': 'tabular_roi_module', 'type': 'list', 'values': [],
+             'limits': ['Manual', 'Polylines']},
+            {'title': 'From module:', 'name': 'tabular_roi_module', 'type': 'list', 'limits': [],
              'visible': False},
             {'title': 'Curvilinear Step:', 'name': 'tabular_step', 'type': 'float',
-             'value': config['scan']['tabular']['curvilinear']},
+             'value': config('scan', 'tabular', 'curvilinear')},
             {'title': 'Positions', 'name': 'tabular_table', 'type': 'table_view',
              'delegate': gutils.SpinBoxDelegate, 'menu': True},
         ]},
@@ -352,9 +357,7 @@ class Scanner(QObject):
         scan_type: type of scan selector
         actuators: list of actuators names
         """
-
-        QLocale.setDefault(QLocale(QLocale.English, QLocale.UnitedStates))
-        super(Scanner, self).__init__()
+        super().__init__()
 
         self.settings_tree = None
         self.setupUI()
@@ -363,7 +366,7 @@ class Scanner(QObject):
         self.settings.child('scan_type').setValue(scan_type)
         # self.scan_selector.settings.child('scan_options', 'scan_type').hide()
         self.scan_selector.scan_select_signal.connect(self.update_scan_2D_positions)
-        self.scan_selector.scan_select_signal.connect(self.update_tabular_positions)
+        self.scan_selector.scan_select_signal.connect(lambda: self.update_tabular_positions())
 
         self.settings.child('tabular_settings', 'tabular_roi_module').setOpts(
             limits=self.scan_selector.sources_names)
@@ -382,13 +385,14 @@ class Scanner(QObject):
                 self.settings.child('scan2D_settings', 'scan2D_loss').setOpts(
                     limits=adaptive_losses['loss2D'], visible=False)
 
-        if actuators != []:
-            self.actuators = actuators
-        else:
-            stypes = scan_types[:]
-            stypes.pop(stypes.index('Sequential'))
-            self.settings.child('scan_type').setLimits(stypes)
-            self.settings.child('scan_type').setValue(stypes[0])
+        self.actuators = actuators
+        # if actuators != []:
+        #     self.actuators = actuators
+        # else:
+        #     stypes = SCAN_TYPES[:]
+        #     stypes.pop(stypes.index('Sequential'))
+        #     self.settings.child('scan_type').setLimits(stypes)
+        #     self.settings.child('scan_type').setValue(stypes[0])
 
         self.scan_selector.widget.setVisible(False)
         self.scan_selector.show_scan_selector(visible=False)
@@ -422,31 +426,31 @@ class Scanner(QObject):
         scan_type = config['scan']['default']
         self.settings.child('scan_type').setValue(scan_type)
 
-        self.settings.child('scan1D_settings', 'scan1D_type').setValue(config['scan']['scan1D']['type'])
-        self.settings.child('scan1D_settings', 'start_1D').setValue(config['scan']['scan1D']['start'])
-        self.settings.child('scan1D_settings', 'stop_1D').setValue(config['scan']['scan1D']['stop'])
-        self.settings.child('scan1D_settings', 'step_1D').setValue(config['scan']['scan1D']['step'])
+        self.settings.child('scan1D_settings', 'scan1D_type').setValue(config('scan', 'scan1D', 'type'))
+        self.settings.child('scan1D_settings', 'start_1D').setValue(config('scan', 'scan1D', 'start'))
+        self.settings.child('scan1D_settings', 'stop_1D').setValue(config('scan', 'scan1D', 'stop'))
+        self.settings.child('scan1D_settings', 'step_1D').setValue(config('scan', 'scan1D', 'step'))
 
-        self.settings.child('scan2D_settings', 'scan2D_type').setValue(config['scan']['scan2D']['type'])
+        self.settings.child('scan2D_settings', 'scan2D_type').setValue(config('scan', 'scan2D', 'type'))
         self.settings.child('scan2D_settings', 'start_2d_axis1').setValue(
-            config['scan']['scan2D']['start1'])
+            config('scan', 'scan2D', 'start1'))
         self.settings.child('scan2D_settings', 'start_2d_axis2').setValue(
-            config['scan']['scan2D']['start2'])
+            config('scan', 'scan2D', 'start2'))
         self.settings.child('scan2D_settings', 'step_2d_axis2').setValue(
-            config['scan']['scan2D']['step1'])
+            config('scan', 'scan2D', 'step1'))
         self.settings.child('scan2D_settings', 'step_2d_axis2').setValue(
-            config['scan']['scan2D']['step2'])
+            config('scan', 'scan2D', 'step2'))
         self.settings.child('scan2D_settings', 'npts_by_axis').setValue(
-            config['scan']['scan2D']['npts'])
+            config('scan', 'scan2D', 'npts'))
         self.settings.child('scan2D_settings', 'stop_2d_axis1').setValue(
-            config['scan']['scan2D']['stop1'])
+            config('scan', 'scan2D', 'stop1'))
         self.settings.child('scan2D_settings', 'stop_2d_axis2').setValue(
-            config['scan']['scan2D']['stop2'])
+            config('scan', 'scan2D', 'stop2'))
 
         self.settings.child('tabular_settings', 'tabular_subtype').setValue(
-            config['scan']['tabular']['type'])
+            config('scan', 'tabular', 'type'))
         self.settings.child('tabular_settings', 'tabular_step').setValue(
-            config['scan']['tabular']['curvilinear'])
+            config('scan', 'tabular', 'curvilinear'))
 
     @property
     def actuators(self):
@@ -523,6 +527,7 @@ class Scanner(QObject):
             self.table_view.load_data_signal.connect(self.table_model.load_txt)
             self.table_view.save_data_signal.connect(self.table_model.save_txt)
 
+
     @property
     def viewers_items(self):
         return self.scan_selector.viewers_items
@@ -536,6 +541,15 @@ class Scanner(QObject):
         self.settings.child('scan2D_settings', 'scan2D_roi_module').setOpts(
             limits=self.scan_selector.sources_names)
 
+    def set_scan_type_and_subtypes(self, scan_type: str, scan_subtype=None):
+        """Convenience function to qzt the main scan type"""
+        if scan_type in SCAN_TYPES:
+            self.settings.child('scan_type').setValue(scan_type)
+
+            if scan_subtype is not None:
+                if scan_subtype in SCAN_SUBTYPES[scan_type]['limits']:
+                    self.settings.child(*SCAN_SUBTYPES[scan_type]['subpath']).setValue(scan_subtype)
+
     def parameter_tree_changed(self, param, changes):
         """
 
@@ -734,26 +748,31 @@ class Scanner(QObject):
         self.scan_params_signal.emit(self.scan_parameters)
         return self.scan_parameters
 
-    def update_tabular_positions(self):
+    def update_tabular_positions(self, positions=None):
         try:
             if self.settings.child('scan_type').value() == 'Tabular':
-                if self.settings.child('tabular_settings',
-                                       'tabular_selection').value() == 'Polylines':  # from ROI
-                    viewer = self.scan_selector.scan_selector_source
+                if positions is None:
+                    if self.settings.child('tabular_settings',
+                                           'tabular_selection').value() == 'Polylines':  # from ROI
+                        viewer = self.scan_selector.scan_selector_source
 
-                    if self.settings.child('tabular_settings', 'tabular_subtype').value() == 'Linear':
-                        positions = self.scan_selector.scan_selector.getArrayIndexes(
-                            spacing=self.settings.child('tabular_settings', 'tabular_step').value())
-                    elif self.settings.child('tabular_settings',
-                                             'tabular_subtype').value() == 'Adaptive':
-                        positions = self.scan_selector.scan_selector.get_vertex()
+                        if self.settings.child('tabular_settings', 'tabular_subtype').value() == 'Linear':
+                            positions = self.scan_selector.scan_selector.getArrayIndexes(
+                                spacing=self.settings.child('tabular_settings', 'tabular_step').value())
+                        elif self.settings.child('tabular_settings',
+                                                 'tabular_subtype').value() == 'Adaptive':
+                            positions = self.scan_selector.scan_selector.get_vertex()
 
-                    steps_x, steps_y = zip(*positions)
-                    steps_x, steps_y = viewer.scale_axis(np.array(steps_x), np.array(steps_y))
-                    positions = np.transpose(np.array([steps_x, steps_y]))
+                        steps_x, steps_y = zip(*positions)
+                        steps_x, steps_y = viewer.scale_axis(np.array(steps_x), np.array(steps_y))
+                        positions = np.transpose(np.array([steps_x, steps_y]))
+                        self.update_model(init_data=positions)
+                    else:
+                        self.update_model()
+                elif isinstance(positions, np.ndarray):
                     self.update_model(init_data=positions)
                 else:
-                    self.update_model()
+                    pass
             else:
                 self.update_model()
         except Exception as e:
@@ -809,22 +828,31 @@ class Scanner(QObject):
             self.settings.child('scan2D_settings', 'scan2D_loss').show(scan_subtype == 'Adaptive')
             if scan_subtype == 'Adaptive':
                 if self.settings.child('scan2D_settings', 'scan2D_loss').value() == 'resolution':
+                    title = 'Minimal feature (%):'
+                    if self.settings.child('scan2D_settings', 'step_2d_axis1').opts['title'] != title:
+                        self.settings.child('scan2D_settings', 'step_2d_axis1').setValue(1)
+                        self.settings.child('scan2D_settings', 'step_2d_axis2').setValue(100)
+
                     self.settings.child('scan2D_settings', 'step_2d_axis1').setOpts(
-                        title='Minimal feature (%):',
-                        tip='Features smaller than this will not be probed first. In percent of maximal scanned area length',
-                        visible=True)
+                        limits=[0, 100], title=title, visible=True,
+                        tip='Features smaller than this will not be probed first. In percent of maximal scanned area'
+                            ' length',
+                        )
                     self.settings.child('scan2D_settings', 'step_2d_axis2').setOpts(
-                        title='Maximal feature (%):',
+                        limits=[0, 100], title='Maximal feature (%):', visible=True,
                         tip='Features bigger than this will be probed first. In percent of maximal scanned area length',
-                        visible=True)
+                        )
+
                 else:
                     self.settings.child('scan2D_settings', 'step_2d_axis1').hide()
                     self.settings.child('scan2D_settings', 'step_2d_axis2').hide()
             else:
-                self.settings.child('scan2D_settings', 'step_2d_axis1').setOpts(title='Step Ax1:',
-                                                                                                tip='Step size for ax1 in actuator units')
-                self.settings.child('scan2D_settings', 'step_2d_axis2').setOpts(title='Step Ax2:',
-                                                                                                tip='Step size for ax2 in actuator units')
+                self.settings.child('scan2D_settings',
+                                    'step_2d_axis1').setOpts(title='Step Ax1:',
+                                                             tip='Step size for ax1 in actuator units')
+                self.settings.child('scan2D_settings',
+                                    'step_2d_axis2').setOpts(title='Step Ax2:',
+                                                             tip='Step size for ax2 in actuator units')
 
             if scan_subtype == 'Spiral':
                 self.settings.child('scan2D_settings',
@@ -892,14 +920,14 @@ class TableModelTabular(gutils.TableModel):
         editable = [True for name in axes_name]
         super().__init__(data, header, editable=editable, **kwargs)
 
-    @pyqtSlot(int)
+    @Slot(int)
     def add_data(self, row, data=None):
         if data is not None:
             self.insert_data(row, [float(d) for d in data])
         else:
             self.insert_data(row, [0. for name in self.header])
 
-    @pyqtSlot(int)
+    @Slot(int)
     def remove_data(self, row):
         self.remove_row(row)
 
@@ -943,8 +971,10 @@ class TableModelSequential(gutils.TableModel):
     def __init__(self, data, **kwargs):
         header = ['Actuator', 'Start', 'Stop', 'Step']
         if 'header' in kwargs:
-            kwargs.pop('header')
+            header = kwargs.pop('header')
         editable = [False, True, True, True]
+        if 'editable' in kwargs:
+            editable = kwargs.pop('editable')
         super().__init__(data, header, editable=editable, **kwargs)
 
     def __repr__(self):
@@ -971,7 +1001,7 @@ class TableModelSequential(gutils.TableModel):
             start = value
         elif col == 2:  # the stop
             stop = value
-        else:  # the step
+        elif col == 3:  # the step
             isstep = True
             step = value
 
@@ -1186,10 +1216,10 @@ def set_scan_sequential(starts, stops, steps):
 
 if __name__ == '__main__':
     app = QtWidgets.QApplication(sys.argv)
-    from PyQt5.QtCore import QThread
+    from qtpy.QtCore import QThread
     from pymodaq.daq_utils.gui_utils import DockArea
     from pyqtgraph.dockarea import Dock
-    from pymodaq.daq_utils.plotting.viewer2D.viewer2D_main import Viewer2D
+    from pymodaq.daq_utils.plotting.data_viewers.viewer2D import Viewer2D
     from pymodaq.daq_utils.plotting.navigator import Navigator
     from pymodaq.daq_viewer.daq_viewer_main import DAQ_Viewer
 
