@@ -1,6 +1,6 @@
 import os
-from PyQt5 import QtWidgets
-from PyQt5.QtCore import QObject, pyqtSlot, pyqtSignal
+from qtpy import QtWidgets
+from qtpy.QtCore import QObject, Slot, Signal
 
 from pymodaq.daq_utils.parameter import ioxml
 from pymodaq.daq_utils.parameter.utils import get_param_path, get_param_from_name, iter_children
@@ -8,14 +8,14 @@ from pyqtgraph.parametertree import Parameter
 from easydict import EasyDict as edict
 
 import numpy as np
-from pymodaq.daq_utils.daq_utils import gauss1D, gauss2D, get_set_local_dir
-
-from pymodaq.daq_utils.daq_utils import ThreadCommand, getLineInfo, load_config
+from pymodaq.daq_utils.daq_utils import gauss1D, gauss2D
+from pymodaq.daq_utils.daq_utils import ThreadCommand, getLineInfo
+from pymodaq.daq_utils.config import Config, get_set_local_dir
 from pymodaq.daq_utils.scanner import ScanParameters
 from pymodaq.daq_utils.tcp_server_client import TCPServer, tcp_parameters
 
 comon_parameters = [{'title': 'Controller Status:', 'name': 'controller_status', 'type': 'list', 'value': 'Master',
-                     'values': ['Master', 'Slave']}, ]
+                     'limits': ['Master', 'Slave']}, ]
 
 local_path = get_set_local_dir()
 # look for eventual calibration files
@@ -26,15 +26,15 @@ if local_path.joinpath('camera_calibrations').is_dir():
             calibs.append(file.stem)
 
 
-config = load_config()
+config = Config()
 
 params = [
     {'title': 'Main Settings:', 'name': 'main_settings', 'expanded': False, 'type': 'group', 'children': [
-        {'title': 'DAQ type:', 'name': 'DAQ_type', 'type': 'list', 'values': ['DAQ0D', 'DAQ1D', 'DAQ2D', 'DAQND'],
+        {'title': 'DAQ type:', 'name': 'DAQ_type', 'type': 'list', 'limits': ['DAQ0D', 'DAQ1D', 'DAQ2D', 'DAQND'],
          'readonly': True},
         {'title': 'Detector type:', 'name': 'detector_type', 'type': 'str', 'value': '', 'readonly': True},
         {'title': 'Nviewers:', 'name': 'Nviewers', 'type': 'int', 'value': 1, 'min': 1, 'default': 1, 'readonly': True},
-        {'title': 'Controller ID:', 'name': 'controller_ID', 'type': 'int', 'value': 0, 'default': 0, 'readonly': True},
+        {'title': 'Controller ID:', 'name': 'controller_ID', 'type': 'int', 'value': 0, 'default': 0, 'readonly': False},
         {'title': 'Show data and process:', 'name': 'show_data', 'type': 'bool', 'value': True, },
         {'title': 'Refresh time (ms):', 'name': 'refresh_time', 'type': 'float', 'value': 50., 'min': 0.},
         {'title': 'Naverage', 'name': 'Naverage', 'type': 'int', 'default': 1, 'value': 1, 'min': 1},
@@ -50,15 +50,15 @@ params = [
              'value': False},
             {'title': 'Connected?:', 'name': 'tcp_connected', 'type': 'led', 'value': False},
             {'title': 'IP address:', 'name': 'ip_address', 'type': 'str',
-             'value': config['network']['tcp-server']['ip']},
-            {'title': 'Port:', 'name': 'port', 'type': 'int', 'value': config['network']['tcp-server']['port']},
+             'value': config('network', 'tcp-server', 'ip')},
+            {'title': 'Port:', 'name': 'port', 'type': 'int', 'value': config('network', 'tcp-server', 'port')},
         ]},
         {'title': 'Overshoot options:', 'name': 'overshoot', 'type': 'group', 'visible': True, 'expanded': False,
          'children': [
              {'title': 'Overshoot:', 'name': 'stop_overshoot', 'type': 'bool', 'value': False},
              {'title': 'Overshoot value:', 'name': 'overshoot_value', 'type': 'float', 'value': 0}]},
         {'title': 'Axis options:', 'name': 'axes', 'type': 'group', 'visible': False, 'expanded': False, 'children': [
-            {'title': 'Use calibration?:', 'name': 'use_calib', 'type': 'list', 'values': calibs},
+            {'title': 'Use calibration?:', 'name': 'use_calib', 'type': 'list', 'limits': calibs},
             {'title': 'X axis:', 'name': 'xaxis', 'type': 'group', 'children': [
                 {'title': 'Label:', 'name': 'xlabel', 'type': 'str', 'value': "x axis"},
                 {'title': 'Units:', 'name': 'xunits', 'type': 'str', 'value': "pxls"},
@@ -85,13 +85,49 @@ params = [
     ]}
 ]
 
+def main(plugin_file=None, init=True):
+    """
+    this method start a DAQ_Viewer object with this defined plugin as detector
+    Returns
+    -------
+    """
+    import sys
+    from qtpy import QtWidgets
+    from pymodaq.daq_utils.gui_utils import DockArea
+    from pymodaq.daq_viewer.daq_viewer_main import DAQ_Viewer
+    from pathlib import Path
+
+    app = QtWidgets.QApplication(sys.argv)
+    if config('style', 'darkstyle'):
+        import qdarkstyle
+        app.setStyleSheet(qdarkstyle.load_stylesheet())
+
+    win = QtWidgets.QMainWindow()
+    area = DockArea()
+    win.setCentralWidget(area)
+    win.resize(1000, 500)
+    win.setWindowTitle('PyMoDAQ Viewer')
+    if plugin_file is None:
+        detector = 'Mock'
+        det_type = f'DAQ0D'
+    else:
+        detector = Path(plugin_file).stem[13:]
+        det_type = f'DAQ{Path(plugin_file).stem[4:6].upper()}'
+    prog = DAQ_Viewer(area, title="Testing", DAQ_type=det_type)
+    win.show()
+    prog.detector = detector
+    if init:
+        prog.init_det()
+
+    sys.exit(app.exec_())
+
 
 class DAQ_Viewer_base(QObject):
     """
         ===================== ===================================
         **Attributes**          **Type**
         *hardware_averaging*    boolean
-        *data_grabed_signal*    instance of pyqtSignal
+        *data_grabed_signal*    instance of Signal
         *params*                list
         *settings*              instance of pyqtgraph Parameter
         *parent*                ???
@@ -104,8 +140,8 @@ class DAQ_Viewer_base(QObject):
     """
     hardware_averaging = False
     live_mode_available = False
-    data_grabed_signal = pyqtSignal(list)
-    data_grabed_signal_temp = pyqtSignal(list)
+    data_grabed_signal = Signal(list)
+    data_grabed_signal_temp = Signal(list)
 
     params = []
 
@@ -135,7 +171,47 @@ class DAQ_Viewer_base(QObject):
         self.x_axis = None
         self.y_axis = None
 
+    def ini_detector(self, controller=None):
+        """
+        Mandatory
+        To be reimplemented in subclass
+        """
+        raise NotImplemented
+
+    def close(self):
+        """
+        Mandatory
+        To be reimplemented in subclass
+        """
+        raise NotImplemented
+
+    def grab_data(self, Naverage=1, **kwargs):
+        """
+        Mandatory
+        To be reimplemented in subclass
+        """
+        raise NotImplemented
+
     def stop(self):
+        """
+        Mandatory
+        To be reimplemented in subclass
+        """
+        raise NotImplemented
+
+    def commit_settings(self, param):
+        """
+        To be reimplemented in subclass
+        """
+        pass
+
+    def update_com(self):
+        """
+        If some communications settings have to be re init
+        To be reimplemented in subclass
+        -------
+
+        """
         pass
 
     def get_axis(self):
@@ -160,20 +236,13 @@ class DAQ_Viewer_base(QObject):
         else:
             print(*status)
 
-    @pyqtSlot(ScanParameters)
+    @Slot(ScanParameters)
     def update_scanner(self, scan_parameters):
         self.scan_parameters = scan_parameters
 
-    def update_com(self):
-        """
-        If some communications settings have to be reinit
-        Returns
-        -------
 
-        """
-        pass
 
-    @pyqtSlot(edict)
+    @Slot(edict)
     def update_settings(self, settings_parameter_dict):
         """
             Update the settings tree from settings_parameter_dict.
@@ -218,11 +287,7 @@ class DAQ_Viewer_base(QObject):
         except Exception as e:
             self.emit_status(ThreadCommand("Update_Status", [str(e), 'log']))
 
-    def commit_settings(self, param):
-        """
-            Not implemented.
-        """
-        pass
+
 
     def send_param_status(self, param, changes):
         """
@@ -255,7 +320,7 @@ class DAQ_Viewer_base(QObject):
 
             pass
 
-    def emit_x_axis(self):
+    def emit_x_axis(self, x_axis=None):
         """
             Convenience function
             Emit the thread command "x_axis" with x_axis as an attribute.
@@ -264,7 +329,9 @@ class DAQ_Viewer_base(QObject):
             --------
             daq_utils.ThreadCommand
         """
-        self.emit_status(ThreadCommand("x_axis", [self.x_axis]))
+        if x_axis is None:
+            x_axis = self.x_axis
+        self.emit_status(ThreadCommand("x_axis", [x_axis]))
 
     def emit_y_axis(self):
         """
@@ -281,7 +348,7 @@ class DAQ_Viewer_TCP_server(DAQ_Viewer_base, TCPServer):
     """
         ================= ==============================
         **Attributes**      **Type**
-        *command_server*    instance of pyqtSignal
+        *command_server*    instance of Signal
         *x_axis*            1D numpy array
         *y_axis*            1D numpy array
         *data*              double precision float array
@@ -292,7 +359,7 @@ class DAQ_Viewer_TCP_server(DAQ_Viewer_base, TCPServer):
         utility_classes.DAQ_TCP_server
     """
     params_GRABBER = []  # parameters of a client grabber
-    command_server = pyqtSignal(list)
+    command_server = Signal(list)
 
     message_list = ["Quit", "Send Data 0D", "Send Data 1D", "Send Data 2D", "Send Data ND", "Status", "Done",
                     "Server Closed", "Info",
